@@ -1,18 +1,19 @@
-import collections
+from __future__ import annotations
+
 import copy
 import json
 import logging
 import os
-import pkg_resources as pkgr
+from collections.abc import Mapping
 from os.path import expanduser
 from pathlib import Path
+from typing import Any, Dict
+
 import jsonschema
-from typing import Dict, Tuple, Optional, Any, Mapping, Union
 
 logger = logging.getLogger(__name__)
 
-EMPTY_USER_SCHEMA = "User schema at {} not found." + \
-                    "User settings won't be validated"
+EMPTY_USER_SCHEMA = "User schema at {} not found. User settings won't be validated"
 MISS_DESC = """ Passing a description without a type does not make sense.
 Description is ignored """
 
@@ -39,15 +40,14 @@ class Config:
     schema_file_name = "qcodesrc_schema.json"
     """Name of schema file"""
     # get abs path of packge config file
-    default_file_name = pkgr.resource_filename(__name__, config_file_name)
+    default_file_name = str(Path(__file__).parent / config_file_name)
     """Filename of default config"""
     current_config_path = default_file_name
     """Path of the last loaded config file"""
     _loaded_config_files = [default_file_name]
 
     # get abs path of schema  file
-    schema_default_file_name = pkgr.resource_filename(__name__,
-                                                      schema_file_name)
+    schema_default_file_name = str(Path(__file__).parent / schema_file_name)
     """Filename of default schema"""
 
     # home dir, os independent
@@ -70,20 +70,20 @@ class Config:
                                                  schema_file_name)
     """Filename of cwd schema"""
 
-    current_schema: Optional['DotDict'] = None
+    current_schema: DotDict | None = None
     """Validators and descriptions of config values"""
-    current_config: Optional['DotDict'] = None
+    current_config: DotDict | None = None
     """Valid config values"""
 
-    defaults: 'DotDict'
+    defaults: DotDict
     """The default configuration"""
-    defaults_schema: 'DotDict'
+    defaults_schema: DotDict
     """The default schema"""
 
-    _diff_config: Dict[str, Any] = {}
-    _diff_schema: Dict[str, Any] = {}
+    _diff_config: dict[str, Any] = {}
+    _diff_schema: dict[str, Any] = {}
 
-    def __init__(self, path: Optional[str] = None) -> None:
+    def __init__(self, path: str | None = None) -> None:
         """
         Args:
             path: Optional path to directory containing
@@ -93,13 +93,13 @@ class Config:
         self.defaults, self.defaults_schema = self.load_default()
         self.update_config()
 
-    def load_default(self) -> Tuple['DotDict', 'DotDict']:
+    def load_default(self) -> tuple[DotDict, DotDict]:
         defaults = self.load_config(self.default_file_name)
         defaults_schema = self.load_config(self.schema_default_file_name)
         self.validate(defaults, defaults_schema)
         return defaults, defaults_schema
 
-    def update_config(self, path: Optional[str] = None) -> Dict[str, Any]:
+    def update_config(self, path: str | None = None) -> dict[str, Any]:
         """
         Load defaults updates with cwd, env, home and the path specified
         and validates.
@@ -155,10 +155,9 @@ class Config:
 
         return config
 
-    def _update_config_from_file(self, file_path: str,
-                                 schema: str,
-                                 config: Dict[str, Any]
-                                 ) -> None:
+    def _update_config_from_file(
+        self, file_path: str, schema: str, config: dict[str, Any]
+    ) -> None:
         """
         Updated ``config`` dictionary with config information from file in
         ``file_path`` that has schema specified in ``schema``
@@ -174,21 +173,32 @@ class Config:
             config = update(config, my_config)
             self.validate(config, self.current_schema, schema)
 
-    def validate(self,
-                 json_config: Optional[Dict[str, Any]] = None,
-                 schema: Optional[Dict[str, Any]] = None,
-                 extra_schema_path: Optional[str] = None
-                 ) -> None:
+    def validate(
+        self,
+        json_config: Mapping[str, Any] | None = None,
+        schema: Mapping[str, Any] | None = None,
+        extra_schema_path: str | None = None,
+    ) -> None:
         """
         Validate configuration; if no arguments are passed, the default
-        validators are used.
+        config is validated against the default schema. If either
+        ``json_config`` or ``schema`` is passed the corresponding
+        default is not used.
 
         Args:
-            json_config: json file to validate
+            json_config: json dictionary to validate
             schema: schema dictionary
             extra_schema_path: schema path that contains extra validators to be
                 added to schema dictionary
         """
+        if schema is None:
+            if self.current_schema is None:
+                raise RuntimeError("Cannot validate as current_schema is None")
+            schema = self.current_schema
+
+        if json_config is None:
+            json_config = self.current_config
+
         if extra_schema_path is not None:
             # add custom validation
             if os.path.isfile(extra_schema_path):
@@ -198,27 +208,21 @@ class Config:
                     # so that default types and values can NEVER
                     # be overwritten
                     new_user = json.load(f)["properties"]["user"]
-                    if schema is None:
-                        if self.current_schema is None:
-                            raise RuntimeError("Cannot validate as "
-                                               "current_schema is None")
-                        schema = self.current_schema
                     user = schema["properties"]['user']
                     user["properties"].update(new_user["properties"])
-                jsonschema.validate(json_config, schema)
             else:
                 logger.warning(EMPTY_USER_SCHEMA.format(extra_schema_path))
-        else:
-            if json_config is None and schema is None:
-                jsonschema.validate(self.current_config, self.current_schema)
-            else:
-                jsonschema.validate(json_config, schema)
 
-    def add(self, key: str, value: Any,
-            value_type: Optional[str] = None,
-            description: Optional[str] = None,
-            default: Optional[Any] = None
-            ) -> None:
+        jsonschema.validate(json_config, schema)
+
+    def add(
+        self,
+        key: str,
+        value: Any,
+        value_type: str | None = None,
+        description: str | None = None,
+        default: Any | None = None,
+    ) -> None:
         """Add custom config value in place
 
         Adds ``key``, ``value`` with optional ``value_type`` to user config and
@@ -277,7 +281,7 @@ class Config:
                 logger.warning(MISS_DESC)
         else:
             # update schema!
-            schema_entry: Dict[str, Dict[str, Union[str, Any]]]
+            schema_entry: dict[str, dict[str, str | Any]]
             schema_entry = {key: {"type": value_type}}
             if description is not None:
                 schema_entry = {
@@ -312,7 +316,7 @@ class Config:
             props["user"].update(schema_entry)
 
     @staticmethod
-    def load_config(path: str) -> 'DotDict':
+    def load_config(path: str) -> DotDict:
         """Load a config JSON file
 
         Args:
@@ -418,14 +422,14 @@ class Config:
         return output
 
 
-class DotDict(Dict[Any, Any]):
+class DotDict(Dict[str, Any]):
     """
     Wrapper dict that allows to get dotted attributes
 
     Requires keys to be strings.
     """
 
-    def __init__(self, value: Optional[Dict[str, Any]] = None):
+    def __init__(self, value: Mapping[str, Any] | None = None):
         if value is None:
             pass
         else:
@@ -449,14 +453,16 @@ class DotDict(Dict[Any, Any]):
         target = dict.__getitem__(self, myKey)
         return target[restOfKey]
 
-    def __contains__(self, key: str) -> bool:  # type: ignore[override]
+    def __contains__(self, key: object) -> bool:
+        if not isinstance(key, str):
+            return False
         if '.' not in key:
-            return dict.__contains__(self, key)
+            return super().__contains__(key)
         myKey, restOfKey = key.split('.', 1)
         target = dict.__getitem__(self, myKey)
         return restOfKey in target
 
-    def __deepcopy__(self, memo: Optional[Dict[Any, Any]]) -> 'DotDict':
+    def __deepcopy__(self, memo: dict[Any, Any] | None) -> DotDict:
         return DotDict(copy.deepcopy(dict(self)))
 
     def __getattr__(self, name: str) -> Any:
@@ -472,10 +478,9 @@ class DotDict(Dict[Any, Any]):
         self.__setitem__(key, value)
 
 
-def update(d: Dict[Any, Any],
-           u: Mapping[Any, Any]) -> Dict[Any, Any]:
+def update(d: dict[Any, Any], u: Mapping[Any, Any]) -> dict[Any, Any]:
     for k, v in u.items():
-        if isinstance(v, collections.abc.Mapping):
+        if isinstance(v, Mapping):
             r = update(d.get(k, {}), v)
             d[k] = r
         else:
