@@ -5,7 +5,7 @@ import logging
 import time
 from contextlib import ExitStack
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Mapping, Sequence, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Mapping, Sequence, Tuple, Union, cast
 
 import numpy as np
 from tqdm.auto import tqdm
@@ -60,6 +60,7 @@ class ParameterSetEvent:
     should_set: bool
     delay: float
     actions: ActionsT
+    get_after_set: bool
 
 
 class _Sweeper:
@@ -228,6 +229,7 @@ class _Sweeper:
                 should_set=should_set,
                 delay=sweep.delay,
                 actions=sweep.post_actions,
+                get_after_set=sweep.get_after_set,
             )
             parameter_set_events.append(event)
         return tuple(parameter_set_events)
@@ -644,7 +646,7 @@ def dond(
         the supplied groups.
     """
     if do_plot is None:
-        do_plot = config.dataset.dond_plot
+        do_plot = cast(bool, config.dataset.dond_plot)
     if show_progress is None:
         show_progress = config.dataset.dond_show_progress
 
@@ -686,6 +688,10 @@ def dond(
         else SequentialParamsCaller(*measurements.measured_all)
     )
 
+    datasavers = []
+    interrupted: Callable[
+        [], KeyboardInterrupt | BreakConditionInterrupt | None
+    ] = lambda: None
     try:
         with _catch_interrupts() as interrupted, ExitStack() as stack, params_meas_caller as call_params_meas:
             datasavers = [
@@ -699,6 +705,7 @@ def dond(
             # https://docs.python.org/3/library/collections.abc.html#collections.abc.Iterable
             # https://github.com/python/cpython/issues/86992#issuecomment-1093897307
             for set_events in tqdm(sweeper, disable=not show_progress):  # type: ignore[call-overload]
+                LOG.debug("Processing set events: %s", set_events)
                 results: dict[ParameterBase, Any] = {}
                 for set_event in set_events:
                     if set_event.should_set:
@@ -707,7 +714,10 @@ def dond(
                             act()
                         time.sleep(set_event.delay)
 
-                    results[set_event.parameter] = set_event.new_value
+                    if set_event.get_after_set:
+                        results[set_event.parameter] = set_event.parameter()
+                    else:
+                        results[set_event.parameter] = set_event.new_value
 
                 meas_value_pair = call_params_meas()
                 for meas_param, value in meas_value_pair:
