@@ -344,7 +344,7 @@ def load_experiment_by_name(
             _repr.append(s)
         _repr_str = "\n".join(_repr)
         if load_last_duplicate:
-            e = exp
+            e = exp  # pyright: ignore
         else:
             raise ValueError(
                 f"Many experiments matching your request" f" found:\n{_repr_str}"
