@@ -9,12 +9,14 @@ import logging
 import os
 from contextlib import contextmanager
 from functools import partial
+from textwrap import wrap
 from typing import TYPE_CHECKING, Any, List, Literal, Optional, Sequence, Tuple, cast
 
 import numpy as np
 
 if TYPE_CHECKING:
     import matplotlib
+    import matplotlib.ticker
     from matplotlib.axes import Axes
     from matplotlib.colorbar import Colorbar
 
@@ -34,7 +36,7 @@ from .data_export import (
 
 log = logging.getLogger(__name__)
 DB = qc.config["core"]["db_location"]
-
+_DEFAULT_COLORMAP = "viridis"
 # NamedData is the structure _get_data_from_ds returns and that plot_by_id
 # uses internally
 NamedData = List[List[DSPlotData]]
@@ -43,11 +45,8 @@ AxesTuple = Tuple["Axes", "Colorbar"]
 AxesTupleList = Tuple[List["Axes"], List[Optional["Colorbar"]]]
 
 
-
 @contextmanager
-def _appropriate_kwargs(plottype: str,
-                        colorbar_present: bool,
-                        **kwargs: Any) -> Any:
+def _appropriate_kwargs(plottype: str, colorbar_present: bool, **kwargs: Any) -> Any:
     """
     NB: Only to be used inside :func"`plot_dataset`.
 
@@ -64,22 +63,24 @@ def _appropriate_kwargs(plottype: str,
     """
 
     def linehandler(**kwargs: Any) -> Any:
-        kwargs.pop('cmap', None)
+        kwargs.pop("cmap", None)
         return kwargs
 
     def heatmaphandler(**kwargs: Any) -> Any:
-        if not(colorbar_present) and 'cmap' not in kwargs:
-            kwargs['cmap'] = qc.config.plotting.default_color_map
+        if not (colorbar_present) and "cmap" not in kwargs:
+            kwargs["cmap"] = qc.config.plotting.default_color_map
         return kwargs
 
-    plot_handler_mapping = {'1D_line': linehandler,
-                            '1D_point': linehandler,
-                            '1D_bar': linehandler,
-                            '2D_point': heatmaphandler,
-                            '2D_grid': heatmaphandler,
-                            '2D_scatter': heatmaphandler,
-                            '2D_equidistant': heatmaphandler,
-                            '2D_unknown': heatmaphandler}
+    plot_handler_mapping = {
+        "1D_line": linehandler,
+        "1D_point": linehandler,
+        "1D_bar": linehandler,
+        "2D_point": heatmaphandler,
+        "2D_grid": heatmaphandler,
+        "2D_scatter": heatmaphandler,
+        "2D_equidistant": heatmaphandler,
+        "2D_unknown": heatmaphandler,
+    }
 
     yield plot_handler_mapping[plottype](**kwargs.copy())
 
@@ -87,7 +88,7 @@ def _appropriate_kwargs(plottype: str,
 def plot_dataset(
     dataset: DataSetProtocol,
     axes: Axes | Sequence[Axes] | None = None,
-    colorbars: Colorbar | Sequence[Colorbar] | None = None,
+    colorbars: Colorbar | Sequence[Colorbar] | Sequence[None] | None = None,
     rescale_axes: bool = True,
     auto_color_scale: bool | None = None,
     cutoff_percentile: tuple[float, float] | float | None = None,
@@ -165,33 +166,37 @@ def plot_dataset(
     FIGURE_KWARGS.remove("kwargs")
     SUBPLOTS_KWARGS = SUBPLOTS_OWN_KWARGS.union(FIGURE_KWARGS)
 
-
     # handle arguments and defaults
-    subplots_kwargs = {k: kwargs.pop(k)
-                       for k in set(kwargs).intersection(SUBPLOTS_KWARGS)}
+    subplots_kwargs = {
+        k: kwargs.pop(k) for k in set(kwargs).intersection(SUBPLOTS_KWARGS)
+    }
 
     # sanitize the complex plotting kwargs
-    if complex_plot_type not in ['real_and_imag', 'mag_and_phase']:
+    if complex_plot_type not in ["real_and_imag", "mag_and_phase"]:
         raise ValueError(
-            f'Invalid complex plot type given. Received {complex_plot_type} '
-            'but can only accept "real_and_imag" or "mag_and_phase".')
-    if complex_plot_phase not in ['radians', 'degrees']:
+            f"Invalid complex plot type given. Received {complex_plot_type} "
+            'but can only accept "real_and_imag" or "mag_and_phase".'
+        )
+    if complex_plot_phase not in ["radians", "degrees"]:
         raise ValueError(
-            f'Invalid complex plot phase given. Received {complex_plot_phase} '
-            'but can only accept "degrees" or "radians".')
+            f"Invalid complex plot phase given. Received {complex_plot_phase} "
+            'but can only accept "degrees" or "radians".'
+        )
     degrees = complex_plot_phase == "degrees"
 
     # Retrieve info about the run for the title
 
     experiment_name = dataset.exp_name
     sample_name = dataset.sample_name
-    title = f"Run #{dataset.captured_run_id}, " \
-            f"Experiment {experiment_name} ({sample_name})"
+    title = (
+        f"Run #{dataset.captured_run_id}, "
+        f"Experiment {experiment_name} ({sample_name})"
+    )
 
     alldata: NamedData = _get_data_from_ds(dataset)
-    alldata = _complex_to_real_preparser(alldata,
-                                         conversion=complex_plot_type,
-                                         degrees=degrees)
+    alldata = _complex_to_real_preparser(
+        alldata, conversion=complex_plot_type, degrees=degrees
+    )
 
     nplots = len(alldata)
 
@@ -209,48 +214,49 @@ def plot_dataset(
             axeslist.append(ax)
     else:
         if len(subplots_kwargs) != 0:
-            raise RuntimeError(f"Error: You cannot provide arguments for the "
-                               f"axes/figure creation if you supply your own "
-                               f"axes. "
-                               f"Provided arguments: {subplots_kwargs}")
+            raise RuntimeError(
+                f"Error: You cannot provide arguments for the "
+                f"axes/figure creation if you supply your own "
+                f"axes. "
+                f"Provided arguments: {subplots_kwargs}"
+            )
         if len(axeslist) != nplots:
-            raise RuntimeError(f"Trying to make {nplots} plots, but"
-                               f"received {len(axeslist)} axes objects.")
+            raise RuntimeError(
+                f"Trying to make {nplots} plots, but"
+                f"received {len(axeslist)} axes objects."
+            )
 
     if colorbars is None:
-        colorbars = len(axeslist)*[None]
-    new_colorbars: list[Colorbar] = []
+        colorbars = len(axeslist) * [None]
+    new_colorbars: list[Colorbar | None] = []
 
     for data, ax, colorbar in zip(alldata, axeslist, colorbars):
 
         if len(data) == 2:  # 1D PLOTTING
-            log.debug(f'Doing a 1D plot with kwargs: {kwargs}')
+            log.debug(f"Doing a 1D plot with kwargs: {kwargs}")
 
             xpoints = data[0]["data"]
             ypoints = data[1]["data"]
 
             plottype = get_1D_plottype(xpoints, ypoints)
-            log.debug(f'Determined plottype: {plottype}')
+            log.debug(f"Determined plottype: {plottype}")
 
-            if plottype == '1D_line':
+            if plottype == "1D_line":
                 # sort for plotting
                 order = xpoints.argsort()
                 xpoints = xpoints[order]
                 ypoints = ypoints[order]
 
-                with _appropriate_kwargs(plottype,
-                                         colorbar is not None, **kwargs) as k:
+                with _appropriate_kwargs(plottype, colorbar is not None, **kwargs) as k:
                     ax.plot(xpoints, ypoints, **k)
-            elif plottype == '1D_point':
-                with _appropriate_kwargs(plottype,
-                                         colorbar is not None, **kwargs) as k:
+            elif plottype == "1D_point":
+                with _appropriate_kwargs(plottype, colorbar is not None, **kwargs) as k:
                     ax.scatter(xpoints, ypoints, **k)
-            elif plottype == '1D_bar':
-                with _appropriate_kwargs(plottype,
-                                         colorbar is not None, **kwargs) as k:
+            elif plottype == "1D_bar":
+                with _appropriate_kwargs(plottype, colorbar is not None, **kwargs) as k:
                     ax.bar(xpoints, ypoints, **k)
             else:
-                raise ValueError('Unknown plottype. Something is way wrong.')
+                raise ValueError("Unknown plottype. Something is way wrong.")
 
             _set_data_axes_labels(ax, data)
 
@@ -259,10 +265,10 @@ def plot_dataset(
 
             new_colorbars.append(None)
 
-            ax.set_title(title)
+            ax.set_title("\n".join(wrap(title)))
 
         elif len(data) == 3:  # 2D PLOTTING
-            log.debug(f'Doing a 2D plot with kwargs: {kwargs}')
+            log.debug(f"Doing a 2D plot with kwargs: {kwargs}")
 
             if data[2]["shape"] is None:
                 xpoints = data[0]["data"].flatten()
@@ -276,46 +282,50 @@ def plot_dataset(
                 zpoints = data[2]["data"]
                 plottype = "2D_grid"
 
-            how_to_plot = {'2D_grid': plot_on_a_plain_grid,
-                           '2D_equidistant': plot_on_a_plain_grid,
-                           '2D_point': plot_2d_scatterplot,
-                           '2D_unknown': plot_2d_scatterplot}
+            how_to_plot = {
+                "2D_grid": plot_on_a_plain_grid,
+                "2D_equidistant": plot_on_a_plain_grid,
+                "2D_point": plot_2d_scatterplot,
+                "2D_unknown": plot_2d_scatterplot,
+            }
             plot_func = how_to_plot[plottype]
 
-            with _appropriate_kwargs(plottype,
-                                     colorbar is not None, **kwargs) as k:
-                ax, colorbar = plot_func(xpoints, ypoints, zpoints,
-                                         ax, colorbar,
-                                         **k)
+            with _appropriate_kwargs(plottype, colorbar is not None, **kwargs) as k:
+                ax, colorbar = plot_func(xpoints, ypoints, zpoints, ax, colorbar, **k)
 
             _set_data_axes_labels(ax, data, colorbar)
 
             if rescale_axes:
                 _rescale_ticks_and_units(ax, data, colorbar)
 
-            auto_color_scale_from_config(colorbar, auto_color_scale,
-                                         zpoints, cutoff_percentile)
+            auto_color_scale_from_config(
+                colorbar, auto_color_scale, zpoints, cutoff_percentile
+            )
 
             new_colorbars.append(colorbar)
 
-            ax.set_title(title)
+            ax.set_title("\n".join(wrap(title)))
 
         else:
-            log.warning('Multi-dimensional data encountered. '
-                        f'parameter {data[-1]["name"]} depends on '
-                        f'{len(data)-1} parameters, cannot plot '
-                        f'that.')
+            log.warning(
+                "Multi-dimensional data encountered. "
+                f'parameter {data[-1]["name"]} depends on '
+                f"{len(data)-1} parameters, cannot plot "
+                f"that."
+            )
             new_colorbars.append(None)
 
     if len(axeslist) != len(new_colorbars):
-        raise RuntimeError("Non equal number of axes. Perhaps colorbar is "
-                           "missing from one of the cases above")
+        raise RuntimeError(
+            "Non equal number of axes. Perhaps colorbar is "
+            "missing from one of the cases above"
+        )
     return axeslist, new_colorbars
 
 
 def plot_and_save_image(
     data: DataSetProtocol, save_pdf: bool = True, save_png: bool = True
-) -> tuple[DataSetProtocol, list[Axes], list[Colorbar | None],]:
+) -> tuple[DataSetProtocol, tuple[Axes, ...], tuple[Colorbar | None, ...],]:
     """
     The utility function to plot results and save the figures either in pdf or
     png or both formats.
@@ -345,7 +355,7 @@ def plot_and_save_image(
         if save_png:
             full_path = os.path.join(png_dir, f"{dataid}_{i}.png")
             ax.figure.savefig(full_path, dpi=500, bbox_inches="tight")
-    res = data, axes, cbs
+    res = data, tuple(axes), tuple(cbs)
     return res
 
 
@@ -369,15 +379,17 @@ def plot_by_id(
     """
 
     dataset = load_by_run_spec(captured_run_id=run_id)
-    return plot_dataset(dataset,
-                        axes,
-                        colorbars,
-                        rescale_axes,
-                        auto_color_scale,
-                        cutoff_percentile,
-                        complex_plot_type,
-                        complex_plot_phase,
-                        **kwargs)
+    return plot_dataset(
+        dataset,
+        axes,
+        colorbars,
+        rescale_axes,
+        auto_color_scale,
+        cutoff_percentile,
+        complex_plot_type,
+        complex_plot_phase,
+        **kwargs,
+    )
 
 
 def _complex_to_real_preparser(
@@ -397,10 +409,12 @@ def _complex_to_real_preparser(
             return the phase in radians
     """
 
-    if conversion not in ['real_and_imag', 'mag_and_phase']:
-        raise ValueError(f'Invalid conversion given. Received {conversion}, '
-                         'but can only accept "real_and_imag" or '
-                         '"mag_and_phase".')
+    if conversion not in ["real_and_imag", "mag_and_phase"]:
+        raise ValueError(
+            f"Invalid conversion given. Received {conversion}, "
+            'but can only accept "real_and_imag" or '
+            '"mag_and_phase".'
+        )
 
     newdata: NamedData = []
 
@@ -456,23 +470,31 @@ def _convert_complex_to_real(
     Should only be called from within _complex_to_real_preparser.
     """
 
-    phase_unit = 'deg' if degrees else 'rad'
+    phase_unit = "deg" if degrees else "rad"
 
     converters = {
-        'data': {'real_and_imag': lambda x: (np.real(x), np.imag(x)),
-                 'mag_and_phase': lambda x: (np.abs(x),
-                                             np.angle(x, deg=degrees))},
-        'labels': {'real_and_imag': lambda l: (l + ' [real]', l + ' [imag]'),
-                   'mag_and_phase': lambda l: (l + ' [mag]', l + ' [phase]')},
-        'units': {'real_and_imag': lambda u: (u, u),
-                  'mag_and_phase': lambda u: (u, phase_unit)},
-        'names': {'real_and_imag': lambda n: (n + '_real', n + '_imag'),
-                  'mag_and_phase': lambda n: (n + '_mag', n + '_phase')}}
+        "data": {
+            "real_and_imag": lambda x: (np.real(x), np.imag(x)),
+            "mag_and_phase": lambda x: (np.abs(x), np.angle(x, deg=degrees)),
+        },
+        "labels": {
+            "real_and_imag": lambda l: (l + " [real]", l + " [imag]"),
+            "mag_and_phase": lambda l: (l + " [mag]", l + " [phase]"),
+        },
+        "units": {
+            "real_and_imag": lambda u: (u, u),
+            "mag_and_phase": lambda u: (u, phase_unit),
+        },
+        "names": {
+            "real_and_imag": lambda n: (n + "_real", n + "_imag"),
+            "mag_and_phase": lambda n: (n + "_mag", n + "_phase"),
+        },
+    }
 
-    new_data = converters['data'][conversion](parameter['data'])
-    new_labels = converters['labels'][conversion](parameter['label'])
-    new_units = converters['units'][conversion](parameter['unit'])
-    new_names = converters['names'][conversion](parameter['name'])
+    new_data = converters["data"][conversion](parameter["data"])
+    new_labels = converters["labels"][conversion](parameter["label"])
+    new_units = converters["units"][conversion](parameter["unit"])
+    new_names = converters["names"][conversion](parameter["name"])
 
     parameter1: DSPlotData = {
         "name": new_names[0],
@@ -494,20 +516,19 @@ def _convert_complex_to_real(
 
 
 def _get_label_of_data(data_dict: DSPlotData) -> str:
-    return data_dict['label'] if data_dict['label'] != '' \
-        else data_dict['name']
+    return data_dict["label"] if data_dict["label"] != "" else data_dict["name"]
 
 
 def _make_axis_label(label: str, unit: str) -> str:
-    label = f'{label}'
-    if unit != '' and unit is not None:
-        label += f' ({unit})'
+    label = f"{label}"
+    if unit != "" and unit is not None:
+        label += f" ({unit})"
     return label
 
 
 def _make_label_for_data_axis(data: Sequence[DSPlotData], axis_index: int) -> str:
     label = _get_label_of_data(data[axis_index])
-    unit = data[axis_index]['unit']
+    unit = data[axis_index]["unit"]
     return _make_axis_label(label, unit)
 
 
@@ -528,7 +549,7 @@ def plot_2d_scatterplot(
     y: np.ndarray,
     z: np.ndarray,
     ax: Axes,
-    colorbar: Colorbar = None,
+    colorbar: Colorbar | None = None,
     **kwargs: Any,
 ) -> AxesTuple:
     """
@@ -548,26 +569,28 @@ def plot_2d_scatterplot(
         The matplotlib axis handles for plot and colorbar
     """
     import matplotlib
+    import matplotlib.cm
 
-    if 'rasterized' in kwargs.keys():
-        rasterized = kwargs.pop('rasterized')
+    if "rasterized" in kwargs.keys():
+        rasterized = kwargs.pop("rasterized")
     else:
         rasterized = len(z) > qc.config.plotting.rasterize_threshold
 
     z_is_stringy = isinstance(z[0], str)
 
     if z_is_stringy:
-        z_strings = np.unique(z)
+        z_strings = [str(elem) for elem in np.unique(z)]
         z = _strings_as_ints(z)
+    else:
+        z_strings = []
 
-    cmap = kwargs.pop('cmap') if 'cmap' in kwargs else None
+    cmap = kwargs.pop("cmap") if "cmap" in kwargs else _DEFAULT_COLORMAP
 
     if z_is_stringy:
-        name = cmap.name if hasattr(cmap, 'name') else 'viridis'
+        name = getattr(cmap, "name", _DEFAULT_COLORMAP)
         cmap = matplotlib.cm.get_cmap(name, len(z_strings))
 
-    mappable = ax.scatter(x=x, y=y, c=z,
-                          rasterized=rasterized, cmap=cmap, **kwargs)
+    mappable = ax.scatter(x=x, y=y, c=z, rasterized=rasterized, cmap=cmap, **kwargs)
 
     if colorbar is not None:
         colorbar = ax.figure.colorbar(mappable, ax=ax, cax=colorbar.ax)
@@ -576,9 +599,8 @@ def plot_2d_scatterplot(
 
     if z_is_stringy:
         N = len(z_strings)
-        f = (N-1)/N
-        colorbar.set_ticks([(n+0.5)*f for n in range(N)])
-        colorbar.set_ticklabels(z_strings)
+        f = (N - 1) / N
+        colorbar.set_ticks([(n + 0.5) * f for n in range(N)], labels=z_strings)
 
     return ax, colorbar
 
@@ -588,7 +610,7 @@ def plot_on_a_plain_grid(
     y: np.ndarray,
     z: np.ndarray,
     ax: Axes,
-    colorbar: Colorbar = None,
+    colorbar: Colorbar | None = None,
     **kwargs: Any,
 ) -> AxesTuple:
     """
@@ -614,8 +636,9 @@ def plot_on_a_plain_grid(
         The matplotlib axes handle for plot and colorbar
     """
     import matplotlib
+    import matplotlib.cm
 
-    log.debug(f'Got kwargs: {kwargs}')
+    log.debug(f"Got kwargs: {kwargs}")
 
     x_is_stringy = isinstance(x[0], str)
     y_is_stringy = isinstance(y[0], str)
@@ -624,14 +647,20 @@ def plot_on_a_plain_grid(
     if x_is_stringy:
         x_strings = np.unique(x)
         x = _strings_as_ints(x)
+    else:
+        x_strings = []
 
     if y_is_stringy:
         y_strings = np.unique(y)
         y = _strings_as_ints(y)
+    else:
+        y_strings = []
 
     if z_is_stringy:
-        z_strings = np.unique(z)
+        z_strings = [str(elem) for elem in np.unique(z)]
         z = _strings_as_ints(z)
+    else:
+        z_strings = []
 
     if x.ndim == 2 and y.ndim == 2 and z.ndim == 2:
         if not np.logical_or(np.any(np.isnan(x)), np.any(np.isnan(y))):
@@ -647,15 +676,15 @@ def plot_on_a_plain_grid(
         x_to_plot, y_to_plot, z_to_plot = reshape_2D_data(x, y, z)
         num_points = x_to_plot.size * y_to_plot.size
 
-    if 'rasterized' in kwargs.keys():
-        rasterized = kwargs.pop('rasterized')
+    if "rasterized" in kwargs.keys():
+        rasterized = kwargs.pop("rasterized")
     else:
         rasterized = num_points > qc.config.plotting.rasterize_threshold
 
-    cmap = kwargs.pop('cmap') if 'cmap' in kwargs else None
+    cmap = kwargs.pop("cmap") if "cmap" in kwargs else _DEFAULT_COLORMAP
 
     if z_is_stringy:
-        name = cmap.name if hasattr(cmap, 'name') else 'viridis'
+        name = getattr(cmap, "name", _DEFAULT_COLORMAP)
         cmap = matplotlib.cm.get_cmap(name, len(z_strings))
 
     colormesh = ax.pcolormesh(
@@ -669,8 +698,7 @@ def plot_on_a_plain_grid(
     )
 
     if x_is_stringy:
-        ax.set_xticks(np.arange(len(np.unique(x_strings))))
-        ax.set_xticklabels(x_strings)
+        ax.set_xticks(np.arange(len(np.unique(x_strings))), labels=x_strings)
 
     if y_is_stringy:
         ax.set_yticks(np.arange(len(np.unique(y_strings))))
@@ -683,9 +711,8 @@ def plot_on_a_plain_grid(
 
     if z_is_stringy:
         N = len(z_strings)
-        f = (N-1)/N
-        colorbar.set_ticks([(n+0.5)*f for n in range(N)])
-        colorbar.set_ticklabels(z_strings)
+        f = (N - 1) / N
+        colorbar.set_ticks([(n + 0.5) * f for n in range(N)], labels=z_strings)
 
     return ax, colorbar
 
@@ -700,10 +727,11 @@ def _clip_nan_from_shaped_data(
         """
         x_row = x_data[:, 0:1]
         y_row = y_data[0:1, :]
-        return (
-            np.nanmax(np.abs(x_data - x_row)) == 0
-            and np.nanmax(np.abs(y_data - y_row)) == 0
-        )
+        # we know that the data here is of a dtype where - operation is defined
+        # but its more trouble than its worthy to explain that to pyright
+        x_diff = np.abs(x_data - x_row)  # pyright: ignore[reportGeneralTypeIssues]
+        y_diff = np.abs(y_data - y_row)  # pyright: ignore[reportGeneralTypeIssues]
+        return np.nanmax(x_diff) == 0 and np.nanmax(y_diff) == 0
 
     if _on_rectilinear_grid_except_nan(x, y):
         # clip any row or column where there are nans in the first row
@@ -774,18 +802,17 @@ def _make_rescaled_ticks_and_units(
     """
     from matplotlib.ticker import FuncFormatter
 
-    unit = data_dict['unit']
+    unit = data_dict["unit"]
 
-    maxval = np.nanmax(np.abs(data_dict['data']))
+    maxval = np.nanmax(np.abs(data_dict["data"]))
     prefix, selected_scale = find_scale_and_prefix(maxval, unit)
 
     new_unit = prefix + unit
     label = _get_label_of_data(data_dict)
     new_label = _make_axis_label(label, new_unit)
 
-    scale_factor = 10**(-selected_scale)
-    ticks_formatter = FuncFormatter(
-        partial(_scale_formatter, factor=scale_factor))
+    scale_factor = 10 ** (-selected_scale)
+    ticks_formatter = FuncFormatter(partial(_scale_formatter, factor=scale_factor))
 
     return ticks_formatter, new_label
 
@@ -800,24 +827,21 @@ def _rescale_ticks_and_units(
     :func:`~_make_rescaled_ticks_and_units`
     """
     # for x axis
-    if not _is_string_valued_array(data[0]['data']):
-        x_ticks_formatter, new_x_label = \
-            _make_rescaled_ticks_and_units(data[0])
+    if not _is_string_valued_array(data[0]["data"]):
+        x_ticks_formatter, new_x_label = _make_rescaled_ticks_and_units(data[0])
         ax.xaxis.set_major_formatter(x_ticks_formatter)
         ax.set_xlabel(new_x_label)
 
     # for y axis
-    if not _is_string_valued_array(data[1]['data']):
-        y_ticks_formatter, new_y_label = \
-            _make_rescaled_ticks_and_units(data[1])
+    if not _is_string_valued_array(data[1]["data"]):
+        y_ticks_formatter, new_y_label = _make_rescaled_ticks_and_units(data[1])
         ax.yaxis.set_major_formatter(y_ticks_formatter)
         ax.set_ylabel(new_y_label)
 
     # for z aka colorbar axis
     if cax is not None and len(data) > 2:
-        if not _is_string_valued_array(data[2]['data']):
-            z_ticks_formatter, new_z_label = \
-                _make_rescaled_ticks_and_units(data[2])
+        if not _is_string_valued_array(data[2]["data"]):
+            z_ticks_formatter, new_z_label = _make_rescaled_ticks_and_units(data[2])
             cax.set_label(new_z_label)
             cax.formatter = z_ticks_formatter
             cax.update_ticks()
