@@ -23,7 +23,7 @@ def _read_settings() -> tuple[dict[str, str | int], dict[str, bool | int | str]]
     """
     # For the limits, there are known default values
     # (known from https://www.sqlite.org/limits.html)
-    DEFAULT_LIMITS: dict[str, str | int | None]
+    DEFAULT_LIMITS: dict[str, str | int]
     DEFAULT_LIMITS = {'MAX_ATTACHED': 10,
                       'MAX_COLUMN': 2000,
                       'MAX_COMPOUND_SELECT': 500,
@@ -40,7 +40,7 @@ def _read_settings() -> tuple[dict[str, str | int], dict[str, bool | int | str]]
     opt_num = 0
     resp = ''
 
-    limits: dict[str, str | int | None]
+    limits: dict[str, str | int]
     limits = DEFAULT_LIMITS.copy()
     settings = {}
 
@@ -54,14 +54,19 @@ def _read_settings() -> tuple[dict[str, str | int], dict[str, bool | int | str]]
         lst = resp.split('=')
         val: str | int | None
         if len(lst) == 2:
-            (param, val) = lst
-            if val.isnumeric():
-                val = int(val)
+            (param, val_str) = lst
+            if val_str.isnumeric():
+                val = int(val_str)
+            else:
+                val = val_str
         else:
             param = lst[0]
             val = None
 
         if param in DEFAULT_LIMITS.keys():
+            # we are only expecting
+            # None val for a setting
+            assert val is not None
             limits.update({param: val})
         elif val:
             settings.update({param: val})
