@@ -6,13 +6,9 @@ Will be deprecated and eventually removed.
 
 from qcodes.parameters import Parameter
 
-from .instrument import (
-    Instrument,
-    InstrumentMeta,
-    InstrumentProtocol,
-    find_or_create_instrument,
-)
+from .instrument import Instrument, InstrumentProtocol, find_or_create_instrument
 from .instrument_base import InstrumentBase
+from .instrument_meta import InstrumentMeta
 
 __all__ = [
     "InstrumentBase",
