@@ -5,7 +5,7 @@ import logging
 import time
 import weakref
 from collections.abc import Mapping
-from typing import TYPE_CHECKING, Any, Protocol, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Protocol, TypeVar, cast, overload
 
 from qcodes.utils import strip_attrs
 from qcodes.validators import Anything
@@ -88,9 +88,9 @@ class Instrument(InstrumentBase, metaclass=InstrumentMeta):
         idstr = ""  # in case self.ask fails
         try:
             idstr = self.ask("*IDN?")
+            idparts: list[str | None] = []
             # form is supposed to be comma-separated, but we've seen
             # other separators occasionally
-            idparts: list[str | None]
             for separator in ",;:":
                 # split into no more than 4 parts, so we don't lose info
                 idparts = [p.strip() for p in idstr.split(separator, 3)]
@@ -225,7 +225,7 @@ class Instrument(InstrumentBase, metaclass=InstrumentMeta):
         cls._instances.add(instance)
 
     @classmethod
-    def instances(cls) -> list[Instrument]:
+    def instances(cls: type[T]) -> list[T]:
         """
         Get all currently defined instances of this instrument class.
 
@@ -259,6 +259,16 @@ class Instrument(InstrumentBase, metaclass=InstrumentMeta):
             if ref is instance:
                 del all_ins[name]
 
+    @overload
+    @classmethod
+    def find_instrument(cls, name: str, instrument_class: None = None) -> Instrument:
+        ...
+
+    @overload
+    @classmethod
+    def find_instrument(cls, name: str, instrument_class: type[T]) -> T:
+        ...
+
     @classmethod
     def find_instrument(cls, name: str, instrument_class: type[T] | None = None) -> T:
         """
