@@ -16,6 +16,7 @@ from qcodes.utils import DelegateAttributes, full_class
 
 if TYPE_CHECKING:
     from qcodes.instrument.channel import ChannelTuple, InstrumentModule
+    from qcodes.logger.instrument_logger import InstrumentLoggerAdapter
 
 from qcodes.utils import QCoDeSDeprecationWarning
 
@@ -82,7 +83,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
         # This is needed for snapshot method to work
         self._meta_attrs = ["name", "label"]
 
-        self.log = get_instrument_logger(self, __name__)
+        self.log: InstrumentLoggerAdapter = get_instrument_logger(self, __name__)
 
     @property
     def label(self) -> str:
@@ -285,7 +286,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
                 update_par = update
             try:
                 snap["parameters"][name] = param.snapshot(update=update_par)
-            except:
+            except Exception:
                 # really log this twice. Once verbose for the UI and once
                 # at lower level with more info for file based loggers
                 self.log.warning("Snapshot: Could not update parameter: %s", name)
@@ -389,7 +390,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
         return None
 
     @property
-    def ancestors(self) -> list[InstrumentBase]:
+    def ancestors(self) -> tuple[InstrumentBase, ...]:
         """
         Ancestors in the form of a list of :class:`InstrumentBase`
 
@@ -398,9 +399,9 @@ class InstrumentBase(Metadatable, DelegateAttributes):
         until the root instrument is reached.
         """
         if self.parent is not None:
-            return [self] + self.parent.ancestors
+            return (self,) + self.parent.ancestors
         else:
-            return [self]
+            return (self,)
 
     @property
     def root_instrument(self) -> InstrumentBase:
@@ -418,8 +419,7 @@ class InstrumentBase(Metadatable, DelegateAttributes):
         A list of all the parts of the instrument name from :meth:`root_instrument`
         to the current :class:`InstrumentModule`.
         """
-        name_parts = [self.short_name]
-        return name_parts
+        return [self.short_name]
 
     @property
     def full_name(self) -> str:
