@@ -1,11 +1,10 @@
-from typing import Any, TypeVar, Sequence, Set, Tuple, Callable
-
 import re
 import warnings
 from functools import wraps
+from typing import Any, Callable, Sequence, Set, Tuple, TypeVar
 
-from qcodes import VisaInstrument
-from qcodes.utils.validators import MultiType, Ints, Enum, Lists
+from qcodes.instrument import VisaInstrument
+from qcodes.validators import Enum, Ints, Lists, MultiType
 
 T = TypeVar('T')
 
@@ -359,3 +358,15 @@ class KeysightB220X(VisaInstrument):
         l = [f'{self._card:01d}{i:02d}{o:02d}' for i, o in paths]
         channel_list = f"(@{','.join(l)})"
         return channel_list
+
+
+class KeysightB2200(KeysightB220X):
+    """
+    QCodes driver for B2200
+    """
+
+
+class KeysightB2201(KeysightB220X):
+    """
+    QCodes driver for B2201
+    """
