@@ -1,19 +1,21 @@
 import re
-from typing import Optional, Tuple, TYPE_CHECKING, Dict, Union, cast, Any
-from typing_extensions import TypedDict
 from collections import namedtuple
+from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, Union, cast
+
 import numpy as np
+from typing_extensions import TypedDict
+
+from qcodes.instrument import InstrumentChannel
 
-from qcodes import InstrumentChannel
-from .message_builder import MessageBuilder
 from . import constants
-from .constants import ModuleKind, SlotNr, MeasurementStatus, ChannelName, ChNr
+from .constants import ChannelName, ChNr, MeasurementStatus, ModuleKind, SlotNr
+from .message_builder import MessageBuilder
 
 if TYPE_CHECKING:
-    from .KeysightB1500_base import KeysightB1500
+    import qcodes.instrument_drivers.Keysight.keysightb1500
 
 
-_FMTResponse = namedtuple('FMTResponse', 'value status channel type')
+_FMTResponse = namedtuple('_FMTResponse', 'value status channel type')
 
 
 class MeasurementNotTaken(Exception):
@@ -283,9 +285,13 @@ class B1500Module(InstrumentChannel):
     """
     MODULE_KIND: ModuleKind
 
-    def __init__(self, parent: 'KeysightB1500', name: Optional[str],
-                 slot_nr: int,
-                 **kwargs: Any):
+    def __init__(
+        self,
+        parent: "qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1500",
+        name: Optional[str],
+        slot_nr: int,
+        **kwargs: Any,
+    ):
         # self.channels will be populated in the concrete module subclasses
         # because channel count is module specific
         self.channels: Tuple[ChNr, ...]
@@ -357,18 +363,24 @@ class B1500Module(InstrumentChannel):
 
 class StatusMixin:
     def __init__(self) -> None:
-        self.param1 = _FMTResponse(None, None, None, None)
-        self.param2 = _FMTResponse(None, None, None, None)
         self.names = tuple(['param1', 'param2'])
 
     def status_summary(self) -> Dict[str, str]:
-        status_array_param1 = self.param1.status
-        status_array_param2 = self.param2.status
+        return_dict: Dict[str, str] = {}
+
+        for name_index, name in enumerate(self.names):
+            param_data: _FMTResponse = getattr(self, f"param{name_index+1}")
+
+            status_array = param_data.status
+            if status_array is None:
+                self_full_name = getattr(self, "full_name", "this")
+                raise MeasurementNotTaken(
+                    f"First run sweep measurement with {self_full_name} "
+                    f"parameter to obtain the data; then it will be possible "
+                    f"to obtain status summary for that data."
+                )
+
+            summary = get_measurement_summary(status_array)
+            return_dict[name] = summary
 
-        if status_array_param1 is None:
-            raise MeasurementNotTaken("First run_sweep to generate the data")
-        summary_param1 = get_measurement_summary(status_array_param1)
-        summary_param2 = get_measurement_summary(status_array_param2)
-        return_dict = {self.names[0]: summary_param1,
-                       self.names[1]: summary_param2}
         return return_dict
