@@ -1,12 +1,12 @@
-from typing import Dict, ClassVar, List, Any
 import time
 from bisect import bisect
+from typing import Any, ClassVar, Dict, List, Optional, Sequence
 
 import numpy as np
 
-from qcodes import VisaInstrument, InstrumentChannel, ChannelList
-from qcodes.instrument.group_parameter import GroupParameter, Group
-from qcodes.utils import validators as vals
+from qcodes import validators as vals
+from qcodes.instrument import ChannelList, InstrumentChannel, VisaInstrument
+from qcodes.parameters import Group, GroupParameter
 
 
 class BaseOutput(InstrumentChannel):
@@ -31,8 +31,12 @@ class BaseOutput(InstrumentChannel):
 
     _input_channel_parameter_kwargs: ClassVar[Dict[str, Any]] = {}
 
-    def __init__(self, parent, output_name, output_index, has_pid: bool=True) \
-            -> None:
+    def __init__(
+            self,
+            parent: "LakeshoreBase",
+            output_name: str,
+            output_index: int,
+            has_pid: bool = True):
         super().__init__(parent, output_name)
 
         self.INVERSE_RANGES: Dict[int, str] = {
@@ -112,7 +116,8 @@ class BaseOutput(InstrumentChannel):
                            docstring='Specifies heater output in percent of '
                                      'the current heater output range.\n'
                                      'Note that when the heater is off, '
-                                     'this parameter will return the value of 0.005.',
+                                     'this parameter will return the value '
+                                     'of 0.005.',
                            get_parser=float,
                            get_cmd=f'HTR? {output_index}',
                            set_cmd=False)
@@ -190,12 +195,12 @@ class BaseOutput(InstrumentChannel):
                            set_cmd=self._set_blocking_t,
                            snapshot_exclude=True)
 
-    def _set_blocking_t(self, temperature):
+    def _set_blocking_t(self, temperature: float) -> None:
         self.set_range_from_temperature(temperature)
         self.setpoint(temperature)
         self.wait_until_set_point_reached()
 
-    def set_range_from_temperature(self, temperature: float):
+    def set_range_from_temperature(self, temperature: float) -> str:
         """
         Sets the output range of this given heater from a given temperature.
 
@@ -232,7 +237,7 @@ class BaseOutput(InstrumentChannel):
         self.output_range(orange)
         return self.output_range()
 
-    def set_setpoint_and_range(self, temperature: float):
+    def set_setpoint_and_range(self, temperature: float) -> None:
         """
         Sets the range from the given temperature, and then sets the setpoint
         to this given temperature.
@@ -241,16 +246,17 @@ class BaseOutput(InstrumentChannel):
         kelvin.
 
         Args:
-            temperature
-                temperature in K
+            temperature: temperature in K
         """
         self.set_range_from_temperature(temperature)
         self.setpoint(temperature)
 
-    def wait_until_set_point_reached(self,
-                                     wait_cycle_time: float=None,
-                                     wait_tolerance: float=None,
-                                     wait_equilibration_time: float=None):
+    def wait_until_set_point_reached(
+            self,
+            wait_cycle_time: Optional[float] = None,
+            wait_tolerance: Optional[float] = None,
+            wait_equilibration_time: Optional[float] = None
+    ) -> None:
         """
         This function runs a loop that monitors the value of the heater's
         input channel until the read values is close to the setpoint value
@@ -261,22 +267,20 @@ class BaseOutput(InstrumentChannel):
         reached within the current range.
 
         Args:
-            wait_cycle_time
-                this time is being waited between the readings (same as
-                `wait_cycle_time` parameter); if None, then the value of the
-                corresponding `wait_cycle_time` parameter is used
-            wait_tolerance
-                this value is used to determine if the reading value is
-                close enough to the setpoint value according to the
+            wait_cycle_time: this time is being waited between the readings
+                (same as `wait_cycle_time` parameter); if None, then the value
+                of the corresponding `wait_cycle_time` parameter is used
+            wait_tolerance: this value is used to determine if the reading
+                value is close enough to the setpoint value according to the
                 following formula:
                 `abs(t_reading - t_setpoint)/t_reading < wait_tolerance`
                 (same as `wait_tolerance` parameter); if None, then the
                 value of the corresponding `wait_tolerance` parameter is used
-            wait_equilibration_time:
-                within this time, the reading value has to stay within the
-                defined tolerance in order for this function to return (same as
-                `wait_equilibration_time` parameter); if None, then the value
-                of the corresponding `wait_equilibration_time` parameter is used
+            wait_equilibration_time: within this time, the reading value has to
+                stay within the defined tolerance in order for this function to
+                return (same as `wait_equilibration_time` parameter);
+                if None, then the value of the corresponding
+                `wait_equilibration_time` parameter is used
         """
         wait_cycle_time = wait_cycle_time or self.wait_cycle_time.get_latest()
         tolerance = wait_tolerance or self.wait_tolerance.get_latest()
@@ -284,9 +288,16 @@ class BaseOutput(InstrumentChannel):
                                    self.wait_equilibration_time.get_latest())
 
         active_channel_id = self.input_channel()
-        active_channel_name_on_instrument = (self.root_instrument
-            .input_channel_parameter_values_to_channel_name_on_instrument[active_channel_id])
-        active_channel = getattr(self.root_instrument, active_channel_name_on_instrument)
+        active_channel_name_on_instrument = (
+            self.root_instrument
+                .input_channel_parameter_values_to_channel_name_on_instrument[
+                active_channel_id
+            ]
+        )
+        active_channel = getattr(
+            self.root_instrument,
+            active_channel_name_on_instrument
+        )
 
         if active_channel.units() != 'kelvin':
             raise ValueError(f"Waiting until the setpoint is reached requires "
@@ -329,7 +340,11 @@ class BaseSensorChannel(InstrumentChannel):
     # the status to a status bit weighting (e.g. {4: 'VMIX OVL'})
     SENSOR_STATUSES: ClassVar[Dict[int, str]] = {}
 
-    def __init__(self, parent, name, channel):
+    def __init__(
+            self,
+            parent: "LakeshoreBase",
+            name: str,
+            channel: str):
         super().__init__(parent, name)
 
         self._channel = channel  # Channel on the temperature controller
@@ -372,7 +387,7 @@ class BaseSensorChannel(InstrumentChannel):
                            vals=vals.Strings(15),
                            label='Sensor name')
 
-    def _decode_sensor_status(self, sum_of_codes: str):
+    def _decode_sensor_status(self, sum_of_codes: str) -> str:
         """
         Parses the sum of status code according to the `SENSOR_STATUSES` using
         an algorithm defined in `_get_sum_terms` method.
@@ -385,10 +400,13 @@ class BaseSensorChannel(InstrumentChannel):
         """
         codes = self._get_sum_terms(list(self.SENSOR_STATUSES.keys()),
                                     int(sum_of_codes))
-        return ", ".join([self.SENSOR_STATUSES[k] for k in codes])
+        return ", ".join(self.SENSOR_STATUSES[k] for k in codes)
 
     @staticmethod
-    def _get_sum_terms(available_terms: List[int], number: int):
+    def _get_sum_terms(
+            available_terms: Sequence[int],
+            number: int
+    ) -> List[int]:
         """
         Returns a list of terms which make the given number when summed up
 
@@ -467,8 +485,8 @@ class LakeshoreBase(VisaInstrument):
     def __init__(self,
                  name: str,
                  address: str,
-                 terminator: str ='\r\n',
-                 **kwargs
+                 terminator: str = '\r\n',
+                 **kwargs: Any
                  ) -> None:
         super().__init__(name, address, terminator=terminator, **kwargs)
 
@@ -478,12 +496,14 @@ class LakeshoreBase(VisaInstrument):
         # Note that `snapshotable` is set to false in order to avoid duplicate
         # snapshotting which otherwise will happen because each channel is also
         # added as a submodule to the instrument.
-        channels = ChannelList(self, "TempSensors", self.CHANNEL_CLASS, snapshotable=False)
+        channels = ChannelList(self,
+                               "TempSensors",
+                               self.CHANNEL_CLASS,
+                               snapshotable=False)
         for name, command in self.channel_name_command.items():
             channel = self.CHANNEL_CLASS(self, name, command)
             channels.append(channel)
             self.add_submodule(name, channel)
-        channels.lock()
-        self.add_submodule("channels", channels)
+        self.add_submodule("channels", channels.to_channel_tuple())
 
         self.connect_message()
