@@ -4,6 +4,7 @@ from functools import partial
 from typing import Any, Callable, Dict, List, Optional, Union, cast
 
 import numpy as np
+import numpy.typing as npt
 from packaging import version
 
 from qcodes.instrument.channel import InstrumentChannel
@@ -51,9 +52,9 @@ def _signal_parser(our_scaling: float, response: str) -> float:
     return float(digits)*their_scaling*our_scaling
 
 
-class MercuryWorkerPS(InstrumentChannel):
+class OxfordMercuryWorkerPS(InstrumentChannel):
     """
-    Class to hold a worker power supply for the MercuryiPS
+    Class to hold a worker power supply for the Oxford MercuryiPS
     """
 
     def __init__(self, parent: VisaInstrument, name: str, UID: str) -> None:
@@ -206,7 +207,13 @@ class MercuryWorkerPS(InstrumentChannel):
         #  the intended value
 
 
-class MercuryiPS(VisaInstrument):
+MercuryWorkerPS = OxfordMercuryWorkerPS
+"""
+Alias for backwards compatibility
+"""
+
+
+class OxfordMercuryiPS(VisaInstrument):
     """
     Driver class for the QCoDeS Oxford Instruments MercuryiPS magnet power
     supply
@@ -235,15 +242,17 @@ class MercuryiPS(VisaInstrument):
                              'function from (x, y, z) -> Bool. Received '
                              f'{type(field_limits)} instead.')
 
-        if visalib:
-            visabackend = visalib.split('@')[1]
-        else:
-            visabackend = 'NI'
-
+        pyvisa_sim_file = kwargs.get("pyvisa_sim_file", None)
         # ensure that a socket is used unless we are in simulation mode
-        if not address.endswith('SOCKET') and visabackend != 'sim':
-            raise ValueError('Incorrect VISA resource name. Must be of type '
-                             'TCPIP0::XXX.XXX.XXX.XXX::7020::SOCKET.')
+        if (
+            not address.endswith("SOCKET")
+            and not address.endswith("@sim")
+            and not pyvisa_sim_file
+        ):
+            raise ValueError(
+                "Incorrect VISA resource name. Must be of type "
+                "TCPIP0::XXX.XXX.XXX.XXX::7020::SOCKET."
+            )
 
         super().__init__(name, address, terminator='\n', visalib=visalib,
                          **kwargs)
@@ -256,7 +265,7 @@ class MercuryiPS(VisaInstrument):
         # TODO: Query instrument to ensure which PSUs are actually present
         for grp in ['GRPX', 'GRPY', 'GRPZ']:
             psu_name = grp
-            psu = MercuryWorkerPS(self, psu_name, grp)
+            psu = OxfordMercuryWorkerPS(self, psu_name, grp)
             self.add_submodule(psu_name, psu)
 
         self._field_limits = (field_limits if field_limits else
@@ -384,7 +393,7 @@ class MercuryiPS(VisaInstrument):
         # actually assign the target on the workers
         cartesian_targ = self._target_vector.get_components('x', 'y', 'z')
         for targ, worker in zip(cartesian_targ, self.submodules.values()):
-            if not isinstance(worker, MercuryWorkerPS):
+            if not isinstance(worker, OxfordMercuryWorkerPS):
                 raise RuntimeError(f"Expected a MercuryWorkerPS but got "
                                    f"{type(worker)}")
             worker.field_target(targ)
@@ -415,7 +424,7 @@ class MercuryiPS(VisaInstrument):
         out of your safe region. Use with care.
         """
         for worker in self.submodules.values():
-            if not isinstance(worker, MercuryWorkerPS):
+            if not isinstance(worker, OxfordMercuryWorkerPS):
                 raise RuntimeError(f"Expected a MercuryWorkerPS but got "
                                    f"{type(worker)}")
             worker.ramp_to_target()
@@ -429,7 +438,7 @@ class MercuryiPS(VisaInstrument):
         self._ramp_simultaneously()
 
         for worker in self.submodules.values():
-            if not isinstance(worker, MercuryWorkerPS):
+            if not isinstance(worker, OxfordMercuryWorkerPS):
                 raise RuntimeError(f"Expected a MercuryWorkerPS but got "
                                    f"{type(worker)}")
             # wait for the ramp to finish, we don't care about the order
@@ -443,9 +452,13 @@ class MercuryiPS(VisaInstrument):
         Ramp all three fields to their target using the 'first-down-then-up'
         sequential ramping procedure. This function is BLOCKING.
         """
-        meas_vals = self._get_measured(['x', 'y', 'z'])
-        targ_vals = self._target_vector.get_components('x', 'y', 'z')
-        order = np.argsort(np.abs(np.array(targ_vals) - np.array(meas_vals)))
+        meas_vals: npt.NDArray[np.floating] = np.array(
+            self._get_measured(["x", "y", "z"])
+        )
+        targ_vals: npt.NDArray[np.floating] = np.array(
+            self._target_vector.get_components("x", "y", "z")
+        )
+        order = np.argsort(np.abs(targ_vals - meas_vals))
 
         for worker in np.array(list(self.submodules.values()))[order]:
             worker.ramp_to_target()
@@ -520,7 +533,7 @@ class MercuryiPS(VisaInstrument):
         meas_vals = cast(List[float], meas_vals)
 
         for cur, worker in zip(meas_vals, self.submodules.values()):
-            if not isinstance(worker, MercuryWorkerPS):
+            if not isinstance(worker, OxfordMercuryWorkerPS):
                 raise RuntimeError(f"Expected a MercuryWorkerPS but got "
                                    f"{type(worker)}")
             if worker.field_target() != cur:
@@ -568,3 +581,7 @@ class MercuryiPS(VisaInstrument):
             base_resp = resp.replace(f'STAT:{base_cmd}', '')
 
         return base_resp
+
+
+MercuryiPS = OxfordMercuryiPS
+"""Alias for backwards compatibility"""
