@@ -5,18 +5,31 @@ import struct
 from collections import abc, defaultdict
 from io import BytesIO
 from time import localtime, sleep
-from typing import Any, Dict, List, NamedTuple, Optional, Sequence, Tuple, Union, cast
+from typing import (
+    Any,
+    Dict,
+    List,
+    Literal,
+    NamedTuple,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    cast,
+)
 
 import numpy as np
 from pyvisa.errors import VisaIOError
-from typing_extensions import Literal
 
 from qcodes import validators as vals
 from qcodes.instrument import VisaInstrument
 
 # conditionally import lomentum for support of lomentum type sequences
 try:
-    from lomentum.tools import get_element_channel_ids, is_subsequence
+    from lomentum.tools import (  # pyright: ignore[reportMissingImports]
+        get_element_channel_ids,
+        is_subsequence,
+    )
     USE_LOMENTUM = True
 except ImportError:
     USE_LOMENTUM = False
