@@ -9,9 +9,8 @@ import traceback
 from collections.abc import Callable, Iterable, Sequence
 from datetime import datetime
 from functools import partial, reduce
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 
-import matplotlib.pyplot as plt
 from IPython.display import clear_output, display
 from ipywidgets import (
     HTML,
@@ -27,12 +26,10 @@ from ipywidgets import (
     VBox,
 )
 from ruamel.yaml import YAML
-from typing_extensions import Literal
 
 import qcodes
-from qcodes.dataset import initialise_or_create_database_at
+from qcodes.dataset import experiments, initialise_or_create_database_at, plot_dataset
 from qcodes.dataset.data_set_protocol import DataSetProtocol
-from qcodes.dataset.plotting import plot_dataset
 
 if TYPE_CHECKING:
     from qcodes.dataset.descriptions.param_spec import ParamSpecBase
@@ -119,8 +116,8 @@ def label(description: str) -> Label:
 
 def _update_nested_dict_browser(
     nested_keys: Sequence[str], nested_dict: dict[Any, Any], box: Box
-) -> Callable[[Button], None]:
-    def update_box(_: Button) -> None:
+) -> Callable[[Button | None], None]:
+    def update_box(_: Button | None) -> None:
         box.children = (_nested_dict_browser(nested_keys, nested_dict, box),)
 
     return update_box
@@ -217,6 +214,8 @@ def nested_dict_browser(
 
 
 def _plot_ds(ds: DataSetProtocol) -> None:
+    import matplotlib.pyplot as plt
+
     plot_dataset(ds)  # might fail
     plt.show()
 
@@ -422,7 +421,7 @@ def _get_run_id_button(ds: DataSetProtocol) -> Box:
     return button_to_text(title, body)
 
 
-def _get_parameters_button(ds: DataSetProtocol) -> VBox:
+def _get_parameters_button(ds: DataSetProtocol) -> Box:
     parameters = _get_parameters(ds)
     title = ds._parameters or ""
     return button_to_text(title, _yaml_dump(parameters))
@@ -517,9 +516,7 @@ def experiments_widget(
     if data_sets is None:
         if db is not None:
             initialise_or_create_database_at(db)
-        data_sets = [
-            ds for exp in qcodes.experiments() for ds in exp.data_sets()
-        ]
+        data_sets = [ds for exp in experiments() for ds in exp.data_sets()]
     if sort_by == "run_id":
         data_sets = sorted(data_sets, key=lambda ds: ds.run_id)
     elif sort_by == "timestamp":
