@@ -17,31 +17,26 @@ list of parameters to monitor:
 
 ``monitor = qcodes.Monitor(param1, param2, param3, ...)``
 """
-
-
-import sys
-import logging
-import os
-import time
-import json
-from contextlib import suppress
-from typing import Dict, Union, Any, Optional, Sequence, Callable, Awaitable
-from collections import defaultdict
+from __future__ import annotations
 
 import asyncio
-from asyncio import CancelledError
-from threading import Thread, Event
-
+import json
+import logging
+import os
 import socketserver
+import time
 import webbrowser
+from asyncio import CancelledError
+from collections import defaultdict
+from contextlib import suppress
+from threading import Event, Thread
+from typing import Any, Awaitable, Callable, Sequence
+
 import websockets
+import websockets.exceptions
+import websockets.server
 
-from qcodes.instrument.parameter import Parameter
-
-if sys.version_info < (3, 7):
-    all_tasks = asyncio.Task.all_tasks
-else:
-    all_tasks = asyncio.all_tasks
+from qcodes.parameters import Parameter
 
 WEBSOCKET_PORT = 5678
 SERVER_PORT = 3000
@@ -49,18 +44,20 @@ SERVER_PORT = 3000
 log = logging.getLogger(__name__)
 
 
-def _get_metadata(*parameters: Parameter) -> Dict[str, Any]:
+def _get_metadata(
+    *parameters: Parameter, use_root_instrument: bool = True
+) -> dict[str, Any]:
     """
     Return a dictionary that contains the parameter metadata grouped by the
     instrument it belongs to.
     """
     metadata_timestamp = time.time()
     # group metadata by instrument
-    metas: dict = defaultdict(list)
+    metas: dict[Any, Any] = defaultdict(list)
     for parameter in parameters:
         # Get the latest value from the parameter,
         # respecting the max_val_age parameter
-        meta: Dict[str, Optional[Union[float, str]]] = {}
+        meta: dict[str, float | str | None] = {}
         meta["value"] = str(parameter.get_latest())
         timestamp = parameter.get_latest.get_timestamp()
         if timestamp is not None:
@@ -71,7 +68,10 @@ def _get_metadata(*parameters: Parameter) -> Dict[str, Any]:
         meta["unit"] = parameter.unit
 
         # find the base instrument that this parameter belongs to
-        baseinst = parameter.root_instrument
+        if use_root_instrument:
+            baseinst = parameter.root_instrument
+        else:
+            baseinst = parameter.instrument
         if baseinst is None:
             metas["Unbound Parameter"].append(meta)
         else:
@@ -87,12 +87,16 @@ def _get_metadata(*parameters: Parameter) -> Dict[str, Any]:
     return state
 
 
-def _handler(parameters: Sequence[Parameter], interval: float) \
-        -> Callable[[websockets.WebSocketServerProtocol, str], Awaitable[None]]:
+def _handler(
+    parameters: Sequence[Parameter], interval: float, use_root_instrument: bool = True
+) -> Callable[[websockets.server.WebSocketServerProtocol, str], Awaitable[None]]:
     """
     Return the websockets server handler.
     """
-    async def server_func(websocket: websockets.WebSocketServerProtocol, _: str) -> None:
+
+    async def server_func(
+        websocket: websockets.server.WebSocketServerProtocol, _: str
+    ) -> None:
         """
         Create a websockets handler that sends parameter values to a listener
         every "interval" seconds.
@@ -101,7 +105,9 @@ def _handler(parameters: Sequence[Parameter], interval: float) \
             try:
                 # Update the parameter values
                 try:
-                    meta = _get_metadata(*parameters)
+                    meta = _get_metadata(
+                        *parameters, use_root_instrument=use_root_instrument
+                    )
                 except ValueError:
                     log.exception("Error getting parameters")
                     break
@@ -124,13 +130,20 @@ class Monitor(Thread):
     """
     running = None
 
-    def __init__(self, *parameters: Parameter, interval: float = 1):
+    def __init__(
+        self,
+        *parameters: Parameter,
+        interval: float = 1,
+        use_root_instrument: bool = True,
+    ):
         """
         Monitor qcodes parameters.
 
         Args:
             *parameters: Parameters to monitor.
             interval: How often one wants to refresh the values.
+            use_root_instrument: Defines if parameters are grouped according to
+                                parameter.root_instrument or parameter.instrument
         """
         super().__init__()
 
@@ -140,13 +153,14 @@ class Monitor(Thread):
                 raise TypeError(f"We can only monitor QCodes "
                                 f"Parameters, not {type(parameter)}")
 
-        self.loop: Optional[asyncio.AbstractEventLoop] = None
-        self.server: Optional[websockets.WebSocketServer] = None
+        self.loop: asyncio.AbstractEventLoop | None = None
+        self._stop_loop_future: asyncio.Future | None = None
         self._parameters = parameters
         self.loop_is_closed = Event()
         self.server_is_started = Event()
-        self.handler = _handler(parameters, interval=interval)
-
+        self.handler = _handler(
+            parameters, interval=interval, use_root_instrument=use_root_instrument
+        )
         log.debug("Start monitoring thread")
         if Monitor.running:
             # stop the old server
@@ -165,24 +179,23 @@ class Monitor(Thread):
         Start the event loop and run forever.
         """
         log.debug("Running Websocket server")
-        self.loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(self.loop)
+
+        async def run_loop() -> None:
+            self.loop = asyncio.get_running_loop()
+            self._stop_loop_future = self.loop.create_future()
+
+            async with websockets.server.serve(
+                self.handler, "127.0.0.1", WEBSOCKET_PORT, close_timeout=1
+            ):
+                self.server_is_started.set()
+                try:
+                    await self._stop_loop_future
+                except asyncio.CancelledError:
+                    log.debug("Websocket server thread shutting down")
+
         try:
-            server_start = websockets.serve(self.handler, '127.0.0.1',
-                                            WEBSOCKET_PORT, close_timeout=1)
-            self.server = self.loop.run_until_complete(server_start)
-            self.server_is_started.set()
-            self.loop.run_forever()
-        except OSError:
-            # The code above may throw an OSError
-            # if the socket cannot be bound
-            log.exception("Server could not be started")
+            asyncio.run(run_loop())
         finally:
-            log.debug("loop stopped")
-            log.debug("Pending tasks at close: %r",
-                      all_tasks(self.loop))
-            self.loop.close()
-            log.debug("loop closed")
             self.loop_is_closed.set()
 
     def update_all(self) -> None:
@@ -202,20 +215,7 @@ class Monitor(Thread):
         self.join()
         Monitor.running = None
 
-    async def __stop_server(self) -> None:
-        log.debug("asking server %r to close", self.server)
-        if self.server is not None:
-            self.server.close()
-        log.debug("waiting for server to close")
-        if self.loop is not None and self.server is not None:
-            await self.loop.create_task(self.server.wait_closed())
-        log.debug("stopping loop")
-        if self.loop is not None:
-            log.debug("Pending tasks at stop: %r",
-                      all_tasks(self.loop))
-            self.loop.stop()
-
-    def join(self, timeout: Optional[float] = None) -> None:
+    def join(self, timeout: float | None = None) -> None:
         """
         Overwrite ``Thread.join`` to make sure server is stopped before
         joining avoiding a potential deadlock.
@@ -227,9 +227,11 @@ class Monitor(Thread):
             log.debug("monitor is dead")
             return
         try:
-            if self.loop is not None:
-                asyncio.run_coroutine_threadsafe(self.__stop_server(),
-                                                 self.loop)
+            if self.loop is not None and self._stop_loop_future is not None:
+                log.debug("Instructing server to stop event loop.")
+                self.loop.call_soon_threadsafe(self._stop_loop_future.cancel)
+            else:
+                log.debug("No event loop found. Cannot stop event loop.")
         except RuntimeError:
             # the above may throw a runtime error if the loop is already
             # stopped in which case there is nothing more to do
@@ -258,18 +260,23 @@ class Monitor(Thread):
         webbrowser.open(f"http://localhost:{SERVER_PORT}")
 
 
-if __name__ == "__main__":
+def main() -> None:
     import http.server
+
     # If this file is run, create a simple webserver that serves a simple
     # website that can be used to view monitored parameters.
-    STATIC_DIR = os.path.join(os.path.dirname(__file__), 'dist')
-    os.chdir(STATIC_DIR)
+    static_dir = os.path.join(os.path.dirname(__file__), "dist")
+    os.chdir(static_dir)
     try:
         log.info("Starting HTTP Server at http://localhost:%i", SERVER_PORT)
         with socketserver.TCPServer(("", SERVER_PORT),
                                     http.server.SimpleHTTPRequestHandler) as httpd:
-            log.debug("serving directory %s", STATIC_DIR)
+            log.debug("serving directory %s", static_dir)
             webbrowser.open(f"http://localhost:{SERVER_PORT}")
             httpd.serve_forever()
     except KeyboardInterrupt:
         log.info("Shutting Down HTTP Server")
+
+
+if __name__ == "__main__":
+    main()
