@@ -1,8 +1,13 @@
+from __future__ import annotations
+
 import copy
 import logging
-from typing import Any, Optional, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Literal, Tuple, cast
+
+if TYPE_CHECKING:
+    import matplotlib
+    import matplotlib.colorbar
 
-import matplotlib
 import numpy as np
 
 from .auto_range import DEFAULT_PERCENTILE, auto_range_iqr
@@ -12,8 +17,12 @@ DEFAULT_COLOR_UNDER = "Cyan"
 
 _LOG = logging.getLogger(__name__)
 
+_EXTEND_TYPE = Literal["neither", "both", "min", "max"]
 
-def _set_colorbar_extend(colorbar: matplotlib.colorbar.Colorbar, extend: str) -> None:
+def _set_colorbar_extend(
+    colorbar: matplotlib.colorbar.Colorbar,
+    extend: _EXTEND_TYPE,
+) -> None:
     """
     Workaround for a missing setter for the extend property of a matplotlib
     colorbar.
@@ -37,16 +46,16 @@ def _set_colorbar_extend(colorbar: matplotlib.colorbar.Colorbar, extend: str) ->
         "min": slice(1, None),
         "max": slice(0, -1),
     }
-    colorbar._inside = _slice_dict[extend]
+    colorbar._inside = _slice_dict[extend]  # pyright: ignore[reportGeneralTypeIssues]
 
 
 def apply_color_scale_limits(
     colorbar: matplotlib.colorbar.Colorbar,
-    new_lim: Tuple[Optional[float], Optional[float]],
-    data_lim: Optional[Tuple[float, float]] = None,
-    data_array: Optional[np.ndarray] = None,
-    color_over: Optional[Any] = DEFAULT_COLOR_OVER,
-    color_under: Optional[Any] = DEFAULT_COLOR_UNDER,
+    new_lim: tuple[float | None, float | None],
+    data_lim: tuple[float, float] | None = None,
+    data_array: np.ndarray | None = None,
+    color_over: Any = DEFAULT_COLOR_OVER,
+    color_under: Any = DEFAULT_COLOR_UNDER,
 ) -> None:
     """
     Applies limits to colorscale and updates extend.
@@ -75,6 +84,8 @@ def apply_color_scale_limits(
         RuntimeError: If not received mesh data. Or if you specified both
         `data_lim` and `data_array`.
     """
+    import matplotlib.collections
+
     # browse the input data and make sure that `data_lim` and `new_lim` are
     # available
     if not isinstance(colorbar.mappable, matplotlib.collections.QuadMesh):
@@ -84,7 +95,7 @@ def apply_color_scale_limits(
         )
     if data_lim is None:
         if data_array is None:
-            data_array = colorbar.mappable.get_array()
+            data_array = cast(np.ndarray, colorbar.mappable.get_array())
         data_lim = np.nanmin(data_array), np.nanmax(data_array)
     else:
         if data_array is not None:
@@ -103,7 +114,7 @@ def apply_color_scale_limits(
     # detect exceeding colorscale and apply new limits
     exceeds_min, exceeds_max = (data_lim[0] < vlim[0], data_lim[1] > vlim[1])
     if exceeds_min and exceeds_max:
-        extend = "both"
+        extend: _EXTEND_TYPE = "both"
     elif exceeds_min:
         extend = "min"
     elif exceeds_max:
@@ -115,15 +126,15 @@ def apply_color_scale_limits(
     cmap.set_over(color_over)
     cmap.set_under(color_under)
     colorbar.mappable.set_cmap(cmap)
-    colorbar.mappable.set_clim(vlim)
+    colorbar.mappable.set_clim(*vlim)
 
 
 def apply_auto_color_scale(
     colorbar: matplotlib.colorbar.Colorbar,
-    data_array: Optional[np.ndarray] = None,
-    cutoff_percentile: Union[Tuple[float, float], float] = DEFAULT_PERCENTILE,
-    color_over: Optional[Any] = DEFAULT_COLOR_OVER,
-    color_under: Optional[Any] = DEFAULT_COLOR_UNDER,
+    data_array: np.ndarray | None = None,
+    cutoff_percentile: tuple[float, float] | float = DEFAULT_PERCENTILE,
+    color_over: Any | None = DEFAULT_COLOR_OVER,
+    color_under: Any | None = DEFAULT_COLOR_UNDER,
 ) -> None:
     """
     Sets the color limits such that outliers are disregarded.
@@ -150,10 +161,12 @@ def apply_auto_color_scale(
     Raises:
         RuntimeError: If not mesh data.
     """
+    import matplotlib.collections
     if data_array is None:
         if not isinstance(colorbar.mappable, matplotlib.collections.QuadMesh):
             raise RuntimeError("Can only scale mesh data.")
-        data_array = colorbar.mappable.get_array()
+        data_array = cast(np.ndarray, colorbar.mappable.get_array())
+    assert data_array is not None
     new_lim = auto_range_iqr(data_array, cutoff_percentile)
     apply_color_scale_limits(
         colorbar,
@@ -166,11 +179,11 @@ def apply_auto_color_scale(
 
 def auto_color_scale_from_config(
     colorbar: matplotlib.colorbar.Colorbar,
-    auto_color_scale: Optional[bool] = None,
-    data_array: Optional[np.ndarray] = None,
-    cutoff_percentile: Optional[Union[Tuple[float, float], float]] = DEFAULT_PERCENTILE,
-    color_over: Optional[Any] = None,
-    color_under: Optional[Any] = None,
+    auto_color_scale: bool | None = None,
+    data_array: np.ndarray | None = None,
+    cutoff_percentile: tuple[float, float] | float | None = DEFAULT_PERCENTILE,
+    color_over: Any | None = None,
+    color_under: Any | None = None,
 ) -> None:
     """
     Sets the color limits such that outliers are disregarded, depending on
