@@ -318,36 +318,36 @@ def test_setting_write_period(wp):
 @given(wp=hst.one_of(hst.integers(), hst.floats(allow_nan=False),
                      hst.text()))
 @pytest.mark.usefixtures("experiment")
+@pytest.mark.usefixtures("reset_config_on_exit")
 def test_setting_write_period_from_config(wp):
-    with reset_config_on_exit():
-        qc.config.dataset.write_period = wp
+    qc.config.dataset.write_period = wp
 
-        if isinstance(wp, str):
-            with pytest.raises(ValueError):
-                Measurement()
-        elif wp < 1e-3:
-            with pytest.raises(ValueError):
-                Measurement()
-        else:
-            meas = Measurement()
-            assert meas.write_period == float(wp)
-            meas.register_custom_parameter(name='dummy')
-            with meas.run() as datasaver:
-                assert datasaver.write_period == float(wp)
+    if isinstance(wp, str):
+        with pytest.raises(ValueError):
+            Measurement()
+    elif wp < 1e-3:
+        with pytest.raises(ValueError):
+            Measurement()
+    else:
+        meas = Measurement()
+        assert meas.write_period == float(wp)
+        meas.register_custom_parameter(name="dummy")
+        with meas.run() as datasaver:
+            assert datasaver.write_period == float(wp)
 
 
 @pytest.mark.parametrize("write_in_background", [True, False])
 @pytest.mark.usefixtures("experiment")
+@pytest.mark.usefixtures("reset_config_on_exit")
 def test_setting_write_in_background_from_config(write_in_background):
-    with reset_config_on_exit():
-        qc.config.dataset.write_in_background = write_in_background
+    qc.config.dataset.write_in_background = write_in_background
 
-        meas = Measurement()
-        meas.register_custom_parameter(name='dummy')
-        with meas.run() as datasaver:
-            ds = datasaver.dataset
-            assert isinstance(ds, DataSet)
-            assert ds._writer_status.write_in_background is write_in_background
+    meas = Measurement()
+    meas.register_custom_parameter(name="dummy")
+    with meas.run() as datasaver:
+        ds = datasaver.dataset
+        assert isinstance(ds, DataSet)
+        assert ds._writer_status.write_in_background is write_in_background
 
 
 @pytest.mark.usefixtures("experiment")
@@ -1691,7 +1691,7 @@ def test_datasaver_export(
     )
 
     mock_type.return_value = export_type
-    mock_path.return_value = path
+    mock_path.return_value = tmp_path
     mock_automatic.return_value = export
     with meas.run(write_in_background=bg_writing) as datasaver:
         datasaver.add_result(
