@@ -1,7 +1,6 @@
 import os
 import random
 import re
-import sys
 import uuid
 from contextlib import contextmanager
 from os.path import getmtime
@@ -210,6 +209,32 @@ def test_real_dataset_1d(two_empty_temp_db_connections, inst):
         assert_array_equal(source_data, target_data)
 
 
+def test_real_dataset_1d_pathlib_path(two_empty_temp_db_connections, inst):
+    source_conn, target_conn = two_empty_temp_db_connections
+
+    source_path = Path(path_to_dbfile(source_conn))
+    target_path = Path(path_to_dbfile(target_conn))
+
+    source_exp = load_or_create_experiment(experiment_name="myexp", conn=source_conn)
+
+    source_dataset, _, _ = do1d(inst.back, 0, 1, 10, 0, inst.plunger, exp=source_exp)
+
+    extract_runs_into_db(source_path, target_path, source_dataset.run_id)
+
+    target_dataset = load_by_guid(source_dataset.guid, conn=target_conn)
+
+    assert source_dataset.the_same_dataset_as(target_dataset)
+    # explicit regression  test for https://github.com/QCoDeS/Qcodes/issues/3953
+    assert source_dataset.description.shapes == {"extract_run_inst_plunger": (10,)}
+    assert source_dataset.description.shapes == target_dataset.description.shapes
+
+    source_data = source_dataset.get_parameter_data()["extract_run_inst_plunger"]
+    target_data = target_dataset.get_parameter_data()["extract_run_inst_plunger"]
+
+    for source_data, target_data in zip(source_data.values(), target_data.values()):
+        assert_array_equal(source_data, target_data)
+
+
 def test_real_dataset_2d(two_empty_temp_db_connections, inst):
     source_conn, target_conn = two_empty_temp_db_connections
 
@@ -513,9 +538,7 @@ def test_load_by_X_functions(two_empty_temp_db_connections,
     assert source_ds_2_2.the_same_dataset_as(test_ds)
 
 
-@pytest.mark.xfail(
-    condition=sys.platform == "win32", reason="Time resolution is too low on windows"
-)
+@pytest.mark.usefixtures("reset_config_on_exit")
 def test_combine_runs(two_empty_temp_db_connections,
                       empty_temp_db_connection,
                       some_interdeps):
@@ -524,6 +547,8 @@ def test_combine_runs(two_empty_temp_db_connections,
     can be reloaded by the original captured_run_id and the experiment
     name.
     """
+    qc.config.GUID_components.GUID_type = "random_sample"
+
     source_conn_1, source_conn_2 = two_empty_temp_db_connections
     target_conn = empty_temp_db_connection
 
@@ -540,6 +565,12 @@ def test_combine_runs(two_empty_temp_db_connections,
     source_2_datasets = [DataSet(conn=source_conn_2,
                                  exp_id=source_2_exp.exp_id) for i in range(10)]
 
+    guids_1 = {dataset.guid for dataset in source_1_datasets}
+    guids_2 = {dataset.guid for dataset in source_2_datasets}
+
+    guids = guids_1 | guids_2
+    assert len(guids) == 20
+
     source_all_datasets = source_1_datasets + source_2_datasets
 
     shuffled_datasets = source_all_datasets.copy()
@@ -581,11 +612,6 @@ def test_combine_runs(two_empty_temp_db_connections,
     cfg = qc.config
     guid_comp = cfg['GUID_components']
 
-    # borrowed fallback logic from generate_guid
-    sampleint = guid_comp['sample']
-    if sampleint == 0:
-        sampleint = int('a'*8, base=16)
-
     for i in range(2, len(lines)):
         split_line = re.split(r'\s+', lines[i].strip())
         mydict = {headers[j]: split_line[j] for j in range(len(split_line))}
@@ -594,7 +620,6 @@ def test_combine_runs(two_empty_temp_db_connections,
         assert ds.captured_counter == int(mydict['captured_counter'])
         assert ds.exp_name == mydict['experiment_name']
         assert ds.sample_name == mydict['sample_name']
-        assert int(mydict['sample_id']) == sampleint
         assert guid_comp['location'] == int(mydict['location'])
         assert guid_comp['work_station'] == int(mydict['work_station'])
 
