@@ -1,7 +1,6 @@
 import io
 import random
 import re
-import sys
 from copy import copy
 from typing import Dict, List, Optional, Sequence, Tuple
 
@@ -11,14 +10,15 @@ import pytest
 from hypothesis import HealthCheck, given, settings
 
 import qcodes as qc
-from qcodes import (
+from qcodes.dataset import (
     experiments,
     load_by_counter,
     load_by_id,
     new_data_set,
     new_experiment,
 )
-from qcodes.dataset.data_set import CompletedError, DataSet
+from qcodes.dataset.data_set import DataSet
+from qcodes.dataset.data_set_protocol import CompletedError
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpecBase
 from qcodes.dataset.descriptions.rundescriber import RunDescriber
@@ -224,8 +224,12 @@ def test_dataset_read_only_properties(dataset):
                        'snapshot', 'snapshot_raw', 'dependent_parameters']
 
     # It is not expected to be possible to set readonly properties
+    # the error message changed in python 3.11
+    # from 'can't set ...' to 'has no setter ...'
     for prop in read_only_props:
-        with pytest.raises(AttributeError, match="can't set attribute"):
+        with pytest.raises(
+            AttributeError, match="(can't set attribute|object has no setter)"
+        ):
             setattr(dataset, prop, True)
 
 
@@ -274,10 +278,10 @@ def test_load_by_id_for_none():
        dataset_name=hst.text(hst.characters(whitelist_categories=_unicode_categories),
                              min_size=1))
 @pytest.mark.usefixtures("empty_temp_db")
-@pytest.mark.xfail(
-    condition=sys.platform == "win32", reason="Time resolution is too low on windows"
-)
+@pytest.mark.usefixtures("reset_config_on_exit")
 def test_add_experiments(experiment_name, sample_name, dataset_name):
+    qc.config.GUID_components.GUID_type = "random_sample"
+
     global n_experiments
     n_experiments += 1
 
@@ -310,7 +314,7 @@ def test_add_experiments(experiment_name, sample_name, dataset_name):
 
 
 @pytest.mark.usefixtures("experiment")
-def test_dependent_parameters():
+def test_dependent_parameters() -> None:
 
     pss: List[ParamSpecBase] = []
 
