@@ -1,11 +1,13 @@
 import json
+import logging
 import os
+from pathlib import Path
 
 import pytest
 import xarray as xr
 
 import qcodes
-from qcodes.dataset import new_data_set
+from qcodes.dataset import get_data_export_path, load_from_netcdf, new_data_set
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpecBase
 from qcodes.dataset.descriptions.versioning import serialization as serial
@@ -13,9 +15,8 @@ from qcodes.dataset.export_config import DataExportType
 from qcodes.dataset.linked_datasets.links import links_to_str
 
 
-@pytest.mark.usefixtures("experiment")
 @pytest.fixture(name="mock_empty_dataset")
-def _make_mock_empty_dataset():
+def _make_mock_empty_dataset(experiment):
     dataset = new_data_set("dataset")
     xparam = ParamSpecBase("x", "numeric")
     yparam = ParamSpecBase("y", "numeric")
@@ -28,9 +29,8 @@ def _make_mock_empty_dataset():
     return dataset
 
 
-@pytest.mark.usefixtures('experiment')
 @pytest.fixture(name="mock_dataset")
-def _make_mock_dataset():
+def _make_mock_dataset(experiment):
     dataset = new_data_set("dataset")
     xparam = ParamSpecBase("x", 'numeric')
     yparam = ParamSpecBase("y", 'numeric')
@@ -46,9 +46,8 @@ def _make_mock_dataset():
     return dataset
 
 
-@pytest.mark.usefixtures('experiment')
 @pytest.fixture(name="mock_dataset_nonunique")
-def _make_mock_dataset_nonunique_index():
+def _make_mock_dataset_nonunique_index(experiment):
     dataset = new_data_set("dataset")
     xparam = ParamSpecBase("x", 'numeric')
     yparam = ParamSpecBase("y", 'numeric')
@@ -64,9 +63,8 @@ def _make_mock_dataset_nonunique_index():
     return dataset
 
 
-@pytest.mark.usefixtures("experiment")
 @pytest.fixture(name="mock_dataset_label_unit")
-def _make_mock_dataset_label_unit():
+def _make_mock_dataset_label_unit(experiment):
     dataset = new_data_set("dataset")
     xparam = ParamSpecBase("x", "numeric", label="x label", unit="x unit")
     yparam = ParamSpecBase("y", "numeric", label="y label", unit="y unit")
@@ -81,9 +79,8 @@ def _make_mock_dataset_label_unit():
     return dataset
 
 
-@pytest.mark.usefixtures("experiment")
 @pytest.fixture(name="mock_dataset_complex")
-def _make_mock_dataset_complex():
+def _make_mock_dataset_complex(experiment):
     dataset = new_data_set("dataset")
     xparam = ParamSpecBase("x", "numeric")
     yparam = ParamSpecBase("y", "complex")
@@ -97,6 +94,33 @@ def _make_mock_dataset_complex():
     return dataset
 
 
+@pytest.fixture(name="mock_dataset_inverted_coords")
+def _make_mock_dataset_inverted_coords(experiment):
+    # this dataset is constructed such
+    # that the two z parameters have inverted
+    # coordinates. You almost certainly
+    # don't want to do this in a real dataset
+    # but it enables the test to check that
+    # the order is preserved.
+    dataset = new_data_set("dataset")
+    xparam = ParamSpecBase("x", "numeric")
+    yparam = ParamSpecBase("y", "numeric")
+    z1param = ParamSpecBase("z1", "numeric")
+    z2param = ParamSpecBase("z2", "numeric")
+    idps = InterDependencies_(
+        dependencies={z1param: (xparam, yparam), z2param: (yparam, xparam)}
+    )
+    dataset.set_interdependencies(idps)
+
+    dataset.mark_started()
+    for x in range(10):
+        for y in range(20, 25):
+            results = [{"x": x, "y": y, "z1": x + y, "z2": x - y}]
+            dataset.add_results(results)
+    dataset.mark_completed()
+    return dataset
+
+
 @pytest.mark.usefixtures('experiment')
 def test_write_data_to_text_file_save(tmp_path_factory):
     dataset = new_data_set("dataset")
@@ -117,7 +141,6 @@ def test_write_data_to_text_file_save(tmp_path_factory):
         assert f.readlines() == ['0.0\t1.0\n']
 
 
-@pytest.mark.usefixtures('experiment')
 def test_write_data_to_text_file_save_multi_keys(tmp_path_factory, mock_dataset):
     tmp_path = tmp_path_factory.mktemp("data_to_text_file_save_multi_keys")
     path = str(tmp_path)
@@ -129,7 +152,6 @@ def test_write_data_to_text_file_save_multi_keys(tmp_path_factory, mock_dataset)
         assert f.readlines() == ['0.0\t2.0\n']
 
 
-@pytest.mark.usefixtures('experiment')
 def test_write_data_to_text_file_save_single_file(tmp_path_factory, mock_dataset):
     tmp_path = tmp_path_factory.mktemp("to_text_file_save_single_file")
     path = str(tmp_path)
@@ -165,7 +187,6 @@ def test_write_data_to_text_file_length_exception(tmp_path):
                                         single_file_name='yz')
 
 
-@pytest.mark.usefixtures('experiment')
 def test_write_data_to_text_file_name_exception(tmp_path, mock_dataset):
     temp_dir = str(tmp_path)
     with pytest.raises(Exception, match='desired file name'):
@@ -173,11 +194,15 @@ def test_write_data_to_text_file_name_exception(tmp_path, mock_dataset):
                                              single_file_name=None)
 
 
-@pytest.mark.usefixtures('experiment')
-def test_export_csv(tmp_path_factory, mock_dataset):
+def test_export_csv(tmp_path_factory, mock_dataset, caplog):
     tmp_path = tmp_path_factory.mktemp("export_csv")
     path = str(tmp_path)
-    mock_dataset.export(export_type="csv", path=path, prefix="qcodes_")
+    with caplog.at_level(logging.INFO):
+        mock_dataset.export(export_type="csv", path=path, prefix="qcodes_")
+
+    assert "Executing on_export callback log_exported_ds" in caplog.messages
+    assert any("Dataset has been exported to" in mes for mes in caplog.messages)
+    assert any("this was triggered manually" in mes for mes in caplog.messages)
 
     mock_dataset.add_metadata("metadata_added_after_export", 69)
 
@@ -189,11 +214,16 @@ def test_export_csv(tmp_path_factory, mock_dataset):
         assert f.readlines() == ['0.0\t1.0\t2.0\n']
 
 
-@pytest.mark.usefixtures('experiment')
-def test_export_netcdf(tmp_path_factory, mock_dataset):
+def test_export_netcdf(tmp_path_factory, mock_dataset, caplog):
     tmp_path = tmp_path_factory.mktemp("export_netcdf")
     path = str(tmp_path)
-    mock_dataset.export(export_type="netcdf", path=path, prefix="qcodes_")
+    with caplog.at_level(logging.INFO):
+        mock_dataset.export(export_type="netcdf", path=path, prefix="qcodes_")
+
+    assert "Executing on_export callback log_exported_ds" in caplog.messages
+    assert any("Dataset has been exported to" in mes for mes in caplog.messages)
+    assert any("this was triggered manually" in mes for mes in caplog.messages)
+
     mock_dataset.add_metadata("metadata_added_after_export", 69)
 
     expected_path = f"qcodes_{mock_dataset.captured_run_id}_{mock_dataset.guid}.nc"
@@ -213,7 +243,21 @@ def test_export_netcdf(tmp_path_factory, mock_dataset):
     assert mock_dataset.export_info.export_paths["nc"] == file_path
 
 
-@pytest.mark.usefixtures("experiment")
+def test_export_netcdf_default_dir(tmp_path_factory, mock_dataset):
+    qcodes.config.dataset.export_path = "{db_location}"
+    mock_dataset.export(export_type="netcdf", prefix="qcodes_")
+    export_path = Path(mock_dataset.export_info.export_paths["nc"])
+    exported_dir = export_path.parent
+    export_dir_stem = exported_dir.stem
+    database_path = Path(qcodes.config.core.db_location)
+    database_file_name = database_path.name
+    database_dir = Path(qcodes.config.core.db_location).parent
+    assert qcodes.config.dataset.export_path == "{db_location}"
+    assert exported_dir.parent == database_dir
+    assert export_dir_stem == database_file_name.replace(".", "_")
+    assert exported_dir == get_data_export_path()
+
+
 def test_export_netcdf_csv(tmp_path_factory, mock_dataset):
 
     tmp_path = tmp_path_factory.mktemp("export_netcdf")
@@ -255,7 +299,6 @@ def test_export_netcdf_csv(tmp_path_factory, mock_dataset):
     assert loaded_new_xr_ds.attrs["metadata_added_after_export_2"] == 696
 
 
-@pytest.mark.usefixtures("experiment")
 def test_export_netcdf_complex_data(tmp_path_factory, mock_dataset_complex):
 
     tmp_path = tmp_path_factory.mktemp("export_netcdf")
@@ -274,7 +317,6 @@ def test_export_netcdf_complex_data(tmp_path_factory, mock_dataset_complex):
     assert df.y.values.tolist() == [1.0 + 1j]
 
 
-@pytest.mark.usefixtures('experiment')
 def test_export_no_or_nonexistent_type_specified(tmp_path_factory, mock_dataset):
     with pytest.raises(ValueError, match="No data export type specified"):
         mock_dataset.export()
@@ -283,21 +325,19 @@ def test_export_no_or_nonexistent_type_specified(tmp_path_factory, mock_dataset)
         mock_dataset.export(export_type="foo")
 
 
-@pytest.mark.usefixtures('experiment')
 def test_export_from_config(tmp_path_factory, mock_dataset, mocker):
     tmp_path = tmp_path_factory.mktemp("export_from_config")
     path = str(tmp_path)
     mock_type = mocker.patch("qcodes.dataset.data_set_protocol.get_data_export_type")
     mock_path = mocker.patch("qcodes.dataset.data_set_protocol.get_data_export_path")
     mock_type.return_value = DataExportType.CSV
-    mock_path.return_value = path
+    mock_path.return_value = tmp_path
     mock_dataset.export()
     assert os.listdir(path) == [
         f"qcodes_{mock_dataset.captured_run_id}_{mock_dataset.guid}.csv"
     ]
 
 
-@pytest.mark.usefixtures("experiment")
 def test_export_from_config_set_name_elements(tmp_path_factory, mock_dataset, mocker):
     tmp_path = tmp_path_factory.mktemp("export_from_config")
     path = str(tmp_path)
@@ -307,7 +347,7 @@ def test_export_from_config_set_name_elements(tmp_path_factory, mock_dataset, mo
         "qcodes.dataset.data_set_protocol.get_data_export_name_elements"
     )
     mock_type.return_value = DataExportType.CSV
-    mock_path.return_value = path
+    mock_path.return_value = tmp_path
     mock_name_elements.return_value = [
         "captured_run_id",
         "guid",
@@ -464,6 +504,32 @@ def test_to_xarray_da_dict_paramspec_metadata_is_preserved(mock_dataset_label_un
             assert xr_da.attrs[spec_name] == spec_value
 
 
+def test_inverted_coords_perserved_on_netcdf_roundtrip(
+    tmp_path_factory, mock_dataset_inverted_coords
+):
+    tmp_path = tmp_path_factory.mktemp("export_netcdf")
+    path = str(tmp_path)
+    mock_dataset_inverted_coords.export(
+        export_type="netcdf", path=tmp_path, prefix="qcodes_"
+    )
+
+    xr_ds = mock_dataset_inverted_coords.to_xarray_dataset()
+    assert xr_ds["z1"].dims == ("x", "y")
+    assert xr_ds["z2"].dims == ("y", "x")
+
+    expected_path = f"qcodes_{mock_dataset_inverted_coords.captured_run_id}_{mock_dataset_inverted_coords.guid}.nc"
+    assert os.listdir(path) == [expected_path]
+    file_path = os.path.join(path, expected_path)
+    ds = load_from_netcdf(file_path)
+
+    with pytest.warns(UserWarning):
+        xr_ds_reimported = ds.to_xarray_dataset()
+
+    assert xr_ds_reimported["z1"].dims == ("x", "y")
+    assert xr_ds_reimported["z2"].dims == ("y", "x")
+    assert xr_ds.identical(xr_ds_reimported)
+
+
 def _get_expected_param_spec_attrs(dataset, dim):
     expected_attrs = dict(dataset.paramspecs[str(dim)]._to_dict())
     expected_attrs["units"] = expected_attrs["unit"]
