@@ -6,10 +6,9 @@ import pytest
 from hypothesis import given, settings
 from numpy.testing import assert_allclose
 
-from qcodes import new_data_set
+from qcodes.dataset import Measurement, new_data_set
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpecBase
-from qcodes.dataset.measurements import Measurement
 from qcodes.dataset.sqlite.connection import atomic_transaction
 from qcodes.tests.common import retry_until_does_not_throw
 
