@@ -18,12 +18,8 @@ def _make_b1500(request):
     except (ValueError, VisaIOError):
         # Either there is no VISA lib installed or there was no real
         # instrument found at the specified address => use simulated instrument
-        import qcodes.instrument.sims as sims
-
-        path_to_yaml = sims.__file__.replace("__init__.py", "keysight_b1500.yaml")
-
         instance = KeysightB1500(
-            "SPA", address="GPIB::1::INSTR", visalib=path_to_yaml + "@sim"
+            "SPA", address="GPIB::1::INSTR", pyvisa_sim_file="keysight_b1500.yaml"
         )
 
     instance.get_status()
