@@ -12,10 +12,18 @@ from qcodes.instrument_drivers.Keysight.keysightb1500.constants import (
 from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1500_base import (
     KeysightB1500,
 )
-from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1511B import B1511B
-from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1517A import B1517A
-from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1520A import B1520A
-from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1530A import B1530A
+from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1511B import (
+    KeysightB1511B,
+)
+from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1517A import (
+    KeysightB1517A,
+)
+from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1520A import (
+    KeysightB1520A,
+)
+from qcodes.instrument_drivers.Keysight.keysightb1500.KeysightB1530A import (
+    KeysightB1530A,
+)
 
 
 def test_make_module_from_model_name(mainframe):
@@ -27,22 +35,22 @@ def test_make_module_from_model_name(mainframe):
     smu = KeysightB1500.from_model_name(model='B1517A', slot_nr=1,
                                         parent=mainframe, name='dummy1')
 
-    assert isinstance(smu, B1517A)
+    assert isinstance(smu, KeysightB1517A)
 
     cmu = KeysightB1500.from_model_name(model='B1520A', slot_nr=2,
                                         parent=mainframe)
 
-    assert isinstance(cmu, B1520A)
+    assert isinstance(cmu, KeysightB1520A)
 
     wgfmu = KeysightB1500.from_model_name(model='B1530A', slot_nr=3,
                                           parent=mainframe)
 
-    assert isinstance(wgfmu, B1530A)
+    assert isinstance(wgfmu, KeysightB1530A)
 
     smu = KeysightB1500.from_model_name(model='B1511B', slot_nr=4,
                                         parent=mainframe, name='dummy2')
 
-    assert isinstance(smu, B1511B)
+    assert isinstance(smu, KeysightB1511B)
 
 
 def test_init(b1500):
