@@ -1,18 +1,15 @@
 import pytest
 
-import qcodes.instrument.sims as sims
 from qcodes.instrument_drivers.Keysight.KeysightAgilent_33XXX import (
     WaveformGenerator_33XXX,
 )
 
-visalib = sims.__file__.replace('__init__.py', 'Keysight_33xxx.yaml@sim')
-
 
 @pytest.fixture(scope='module')
 def driver():
-    kw_sim = WaveformGenerator_33XXX('kw_sim',
-                                      address='GPIB::1::INSTR',
-                                      visalib=visalib)
+    kw_sim = WaveformGenerator_33XXX(
+        "kw_sim", address="GPIB::1::INSTR", pyvisa_sim_file="Keysight_33xxx.yaml"
+    )
     yield kw_sim
 
     kw_sim.close()
