@@ -1,16 +1,13 @@
 import pytest
 
-import qcodes.instrument.sims as sims
 import qcodes.instrument_drivers.Keysight.Keysight_N6705B as N6705B
 
-visalib = sims.__file__.replace('__init__.py', 'Keysight_N6705B.yaml@sim')
 
-
-@pytest.fixture(scope='module')
-def driver():
-    driver = N6705B.N6705B('N6705B',
-                           address="GPIB::1::INSTR",
-                           visalib=visalib)
+@pytest.fixture(scope="module", name="driver")
+def _make_driver():
+    driver = N6705B.N6705B(
+        "N6705B", address="GPIB::1::INSTR", pyvisa_sim_file="Keysight_N6705B.yaml"
+    )
     yield driver
     driver.close()
 
