@@ -5,17 +5,15 @@ import numpy as np
 import pytest
 from hypothesis import HealthCheck, settings
 
-import qcodes.instrument.sims as sims
 from qcodes.instrument_drivers.oxford.MercuryiPS_VISA import MercuryiPS
 from qcodes.math_utils.field_vector import FieldVector
 
-visalib = sims.__file__.replace('__init__.py', 'MercuryiPS.yaml@sim')
-
 
 @pytest.fixture(scope='function')
 def driver():
-    mips = MercuryiPS('mips', address='GPIB::1::INSTR',
-                      visalib=visalib)
+    mips = MercuryiPS(
+        "mips", address="GPIB::1::INSTR", pyvisa_sim_file="MercuryiPS.yaml"
+    )
     yield mips
     mips.close()
 
@@ -29,8 +27,12 @@ def driver_spher_lim():
         """
         return np.sqrt(x**2 + y**2 + z**2) <= 2
 
-    mips_sl = MercuryiPS('mips_sl', address='GPIB::1::INSTR',
-                         visalib=visalib, field_limits=spherical_limits)
+    mips_sl = MercuryiPS(
+        "mips_sl",
+        address="GPIB::1::INSTR",
+        pyvisa_sim_file="MercuryiPS.yaml",
+        field_limits=spherical_limits,
+    )
 
     yield mips_sl
     mips_sl.close()
@@ -47,8 +49,12 @@ def driver_cyl_lim():
 
         return rho_check and z_check
 
-    mips_cl = MercuryiPS('mips_cl', address='GPIB::1::INSTR',
-                         visalib=visalib, field_limits=cylindrical_limits)
+    mips_cl = MercuryiPS(
+        "mips_cl",
+        address="GPIB::1::INSTR",
+        pyvisa_sim_file="MercuryiPS.yaml",
+        field_limits=cylindrical_limits,
+    )
 
     yield mips_cl
     mips_cl.close()
@@ -86,8 +92,12 @@ def test_vector_ramp_rate(driver):
 def test_wrong_field_limit_raises():
     # check that a non-callable input fails
     with pytest.raises(ValueError):
-        MercuryiPS('mips', address='GPIB::1::INSTR', visalib=visalib,
-                   field_limits=0)
+        MercuryiPS(
+            "mips",
+            address="GPIB::1::INSTR",
+            pyvisa_sim_file="MercuryiPS.yaml",
+            field_limits=0,
+        )
 
 
 @settings(suppress_health_check=(HealthCheck.function_scoped_fixture,))
