@@ -1,18 +1,16 @@
 import pytest
 
-import qcodes.instrument.sims as sims
 from qcodes.instrument_drivers.rohde_schwarz.RTO1000 import RTO1000
 
-visalib = sims.__file__.replace('__init__.py', 'RTO_1000.yaml@sim')
-
 
 @pytest.fixture(scope='function')
 def driver():
-    rto_sim = RTO1000('rto_sim',
-                      address='GPIB::1::INSTR',
-                      visalib=visalib,
-                      model='RTO1044'
-                      )
+    rto_sim = RTO1000(
+        "rto_sim",
+        address="GPIB::1::INSTR",
+        pyvisa_sim_file="RTO_1000.yaml",
+        model="RTO1044",
+    )
     yield rto_sim
 
     rto_sim.close()
