@@ -1,19 +1,18 @@
 import numpy as np
 import pytest
 
-import qcodes.instrument.sims as sims
 from qcodes.instrument_drivers.tektronix.AWG5014 import Tektronix_AWG5014
 
-visalib = sims.__file__.replace('__init__.py', 'Tektronix_AWG5014C.yaml@sim')
-
 
 @pytest.fixture(scope='function')
 def awg():
-    awg_sim = Tektronix_AWG5014('awg_sim',
-                                address='GPIB0::1::INSTR',
-                                timeout=1,
-                                terminator='\n',
-                                visalib=visalib)
+    awg_sim = Tektronix_AWG5014(
+        "awg_sim",
+        address="GPIB0::1::INSTR",
+        timeout=1,
+        terminator="\n",
+        pyvisa_sim_file="Tektronix_AWG5014C.yaml",
+    )
     yield awg_sim
 
     awg_sim.close()
