@@ -2,17 +2,14 @@ import os
 
 import pytest
 
-import qcodes.instrument.sims as sims
 from qcodes.instrument_drivers.tektronix.AWG5208 import AWG5208
 
-visalib = sims.__file__.replace('__init__.py', 'Tektronix_AWG5208.yaml@sim')
-
 
 @pytest.fixture(scope='function')
 def awg():
-    awg_sim = AWG5208('awg_sim',
-                      address='GPIB0::1::INSTR',
-                      visalib=visalib)
+    awg_sim = AWG5208(
+        "awg_sim", address="GPIB0::1::INSTR", pyvisa_sim_file="Tektronix_AWG5208.yaml"
+    )
     yield awg_sim
 
     awg_sim.close()
