@@ -1,14 +1,13 @@
 import pytest
 
-import qcodes.instrument.sims as sims
 from qcodes.instrument_drivers.yokogawa import YokogawaGS200
 
-VISALIB = sims.__file__.replace("__init__.py", "Yokogawa_GS200.yaml@sim")
-
 
 @pytest.fixture(scope="function", name="gs200")
 def _make_gs200():
-    gs200 = YokogawaGS200("GS200", address="GPIB0::1::INSTR", visalib=VISALIB)
+    gs200 = YokogawaGS200(
+        "GS200", address="GPIB0::1::INSTR", pyvisa_sim_file="Yokogawa_GS200.yaml"
+    )
     yield gs200
 
     gs200.close()
