@@ -1,9 +1,20 @@
-from collections import OrderedDict, UserDict
 import json
+import warnings
+from collections import OrderedDict, UserDict
 
+import hypothesis.strategies as hst
 import numpy as np
 import pytest
-from qcodes.utils.helpers import NumpyJSONEncoder
+from hypothesis import given
+
+with warnings.catch_warnings():
+    # this context manager can be removed when uncertainties
+    # no longer triggers deprecation warnings
+    warnings.simplefilter("ignore", category=DeprecationWarning)
+    import uncertainties
+
+from qcodes.utils import NumpyJSONEncoder
+from qcodes.utils.types import numpy_complex, numpy_floats, numpy_ints
 
 
 def test_python_types():
@@ -30,20 +41,20 @@ def test_complex_types():
     e = NumpyJSONEncoder()
     assert e.encode(complex(1, 2)) == \
            '{"__dtype__": "complex", "re": 1.0, "im": 2.0}'
-    assert e.encode(np.complex(1, 2)) == \
-           '{"__dtype__": "complex", "re": 1.0, "im": 2.0}'
-    assert e.encode(np.complex64(complex(1, 2))) == \
-           '{"__dtype__": "complex", "re": 1.0, "im": 2.0}'
+    for complex_type in numpy_complex:
+        assert e.encode(complex_type(complex(1, 2))) == \
+               '{"__dtype__": "complex", "re": 1.0, "im": 2.0}'
+
+
+def test_UFloat_type():
+    e = NumpyJSONEncoder()
+    assert e.encode(uncertainties.ufloat(1.0, 2.0)) == \
+           '{"__dtype__": "UFloat", "nominal_value": 1.0, "std_dev": 2.0}'
 
 
 def test_numpy_int_types():
     e = NumpyJSONEncoder()
 
-    numpy_ints = (np.int, np.int_, np.int8, np.int16, np.int32,
-                  np.int64, np.intc, np.intp,
-                  np.uint, np.uint8, np.uint16, np.uint32, np.uint64,
-                  np.uintc, np.uintp)
-
     for int_type in numpy_ints:
         assert e.encode(int_type(3)) == '3'
 
@@ -51,9 +62,6 @@ def test_numpy_int_types():
 def test_numpy_float_types():
     e = NumpyJSONEncoder()
 
-    numpy_floats = (np.float, np.float_, np.float16, np.float32,
-                    np.float64)
-
     for float_type in numpy_floats:
         assert e.encode(float_type(2.5)) == '2.5'
 
@@ -118,6 +126,7 @@ def test_object_with_serialization_method():
 class SomeUserDict(UserDict):
     pass
 
+
 EXAMPLEMETADATA = {
     'name': 'Rapunzel',
     'age': np.int64(12),
@@ -161,3 +170,26 @@ def test_numpy_encoder_examplemetadata():
         'myuserdict': {'a': 1}
     }
     assert metadata == data_dict
+
+
+@given(bytes_to_encode=hst.binary(max_size=100))
+def test_bytes(bytes_to_encode):
+    e = NumpyJSONEncoder()
+    v = e.encode(bytes_to_encode)
+
+    default_encoder = json.JSONEncoder()
+    # encoding bytes is the same as using the
+    # default encode on the str value of the bytes
+    assert v == default_encoder.encode(str(bytes_to_encode))
+
+
+@given(bytes_to_encode=hst.binary(max_size=100))
+def test_bytes_array(bytes_to_encode):
+    e = NumpyJSONEncoder()
+    value = bytearray(bytes_to_encode)
+    v = e.encode(value)
+
+    default_encoder = json.JSONEncoder()
+    # encoding bytes is the same as using the
+    # default encode on the str value of the bytes array
+    assert v == default_encoder.encode(str(value))
