@@ -5,11 +5,14 @@ import pytest
 from hypothesis import given
 from hypothesis.extra.numpy import complex_number_dtypes
 
-from qcodes.utils.types import (concrete_complex_types, numpy_concrete_floats,
-                                numpy_concrete_ints,
-                                numpy_non_concrete_floats_instantiable,
-                                numpy_non_concrete_ints_instantiable)
-from qcodes.utils.validators import Arrays
+from qcodes.utils.types import (
+    concrete_complex_types,
+    numpy_concrete_floats,
+    numpy_concrete_ints,
+    numpy_non_concrete_floats_instantiable,
+    numpy_non_concrete_ints_instantiable,
+)
+from qcodes.validators import Arrays
 
 
 def test_type():
