@@ -7,7 +7,7 @@ from qcodes.validators import Bool
 
 from .conftest import AClass, a_func
 
-BOOLS = [True, False, np.bool8(True), np.bool8(False)]
+BOOLS = [True, False, np.bool_(True), np.bool_(False)]
 NOTBOOLS = [0, 1, 10, -1, 100, 1000000, int(-1e15), int(1e15),
             0.1, -0.1, 1.0, 3.5, -2.3e6, 5.5e15, 1.34e-10, -2.5e-5,
             math.pi, math.e, '', None, float("nan"), float("inf"),
