@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import warnings
-from typing import Any, Optional, Sequence
+from collections.abc import Sequence
+from typing import Any
 
 import numpy as np
 from numpy import VisibleDeprecationWarning
@@ -7,7 +10,7 @@ from numpy import VisibleDeprecationWarning
 
 def list_of_data_to_maybe_ragged_nd_array(
     column_data: Sequence[Any],
-    dtype: Optional[type] = None,
+    dtype: type | None = None,
 ) -> np.ndarray:
     """
     Convert a (nested) Sequence of data to numpy arrays. Handle that
@@ -22,16 +25,17 @@ def list_of_data_to_maybe_ragged_nd_array(
                 category=VisibleDeprecationWarning,
                 message="Creating an ndarray from ragged nested sequences",
             )
-            # numpy warns here and coming versions
+            # numpy < 1.24 warns here and coming versions
             # will eventually raise
             # for ragged arrays if you don't explicitly set
             # dtype=object
             # It is time consuming to detect ragged arrays here
             # and it is expected to be a relatively rare situation
             # so fallback to object if the regular dtype fail
+            # the warning filter here can be removed once
+            # we drop support for numpy < 1.24
             data = np.array(column_data, dtype=dtype)
-    except:
-        # Not clear which error to catch here. This will only be clarified
-        # once numpy actually starts to raise here.
+    except ValueError:
+        # From numpy 1.24 this throws a ValueError
         data = np.array(column_data, dtype=object)
     return data
